#ifdef GL_VERSION_1_0
if (!strncmp(name, "GL_", 3)) {
	i(GL_FALSE)
	i(GL_TRUE)
	i(GL_BYTE)
	i(GL_UNSIGNED_BYTE)
	i(GL_SHORT)
	i(GL_UNSIGNED_SHORT)
	i(GL_INT)
	i(GL_UNSIGNED_INT)
	i(GL_FLOAT)
	i(GL_DOUBLE)
	i(GL_2_BYTES)
	i(GL_3_BYTES)
	i(GL_4_BYTES)
	i(GL_LINES)
	i(GL_POINTS)
	i(GL_LINE_STRIP)
	i(GL_LINE_LOOP)
	i(GL_TRIANGLES)
	i(GL_TRIANGLE_STRIP)
	i(GL_TRIANGLE_FAN)
	i(GL_QUADS)
	i(GL_QUAD_STRIP)
	i(GL_POLYGON)
	i(GL_EDGE_FLAG)
	i(GL_V2F)
	i(GL_V3F)
	i(GL_C4UB_V2F)
	i(GL_C4UB_V3F)
	i(GL_C3F_V3F)
	i(GL_N3F_V3F)
	i(GL_C4F_N3F_V3F)
	i(GL_T2F_V3F)
	i(GL_T4F_V4F)
	i(GL_T2F_C4UB_V3F)
	i(GL_T2F_C3F_V3F)
	i(GL_T2F_N3F_V3F)
	i(GL_T2F_C4F_N3F_V3F)
	i(GL_T4F_C4F_N3F_V4F)
	i(GL_MATRIX_MODE)
	i(GL_MODELVIEW)
	i(GL_PROJECTION)
	i(GL_TEXTURE)
	i(GL_POINT_SMOOTH)
	i(GL_POINT_SIZE)
	i(GL_POINT_SIZE_GRANULARITY)
	i(GL_POINT_SIZE_RANGE)
	i(GL_LINE_SMOOTH)
	i(GL_LINE_STIPPLE)
	i(GL_LINE_STIPPLE_PATTERN)
	i(GL_LINE_STIPPLE_REPEAT)
	i(GL_LINE_WIDTH)
	i(GL_LINE_WIDTH_GRANULARITY)
	i(GL_LINE_WIDTH_RANGE)
	i(GL_POINT)
	i(GL_LINE)
	i(GL_FILL)
	i(GL_CCW)
	i(GL_CW)
	i(GL_FRONT)
	i(GL_BACK)
	i(GL_CULL_FACE)
	i(GL_CULL_FACE_MODE)
	i(GL_POLYGON_SMOOTH)
	i(GL_POLYGON_STIPPLE)
	i(GL_FRONT_FACE)
	i(GL_POLYGON_MODE)
	i(GL_COMPILE)
	i(GL_COMPILE_AND_EXECUTE)
	i(GL_LIST_BASE)
	i(GL_LIST_INDEX)
	i(GL_LIST_MODE)
	i(GL_NEVER)
	i(GL_LESS)
	i(GL_GEQUAL)
	i(GL_LEQUAL)
	i(GL_GREATER)
	i(GL_NOTEQUAL)
	i(GL_EQUAL)
	i(GL_ALWAYS)
	i(GL_DEPTH_TEST)
	i(GL_DEPTH_BITS)
	i(GL_DEPTH_CLEAR_VALUE)
	i(GL_DEPTH_FUNC)
	i(GL_DEPTH_RANGE)
	i(GL_DEPTH_WRITEMASK)
	i(GL_DEPTH_COMPONENT)
	i(GL_LIGHTING)
	i(GL_LIGHT0)
	i(GL_LIGHT1)
	i(GL_LIGHT2)
	i(GL_LIGHT3)
	i(GL_LIGHT4)
	i(GL_LIGHT5)
	i(GL_LIGHT6)
	i(GL_LIGHT7)
	i(GL_SPOT_EXPONENT)
	i(GL_SPOT_CUTOFF)
	i(GL_CONSTANT_ATTENUATION)
	i(GL_LINEAR_ATTENUATION)
	i(GL_QUADRATIC_ATTENUATION)
	i(GL_AMBIENT)
	i(GL_DIFFUSE)
	i(GL_SPECULAR)
	i(GL_SHININESS)
	i(GL_EMISSION)
	i(GL_POSITION)
	i(GL_SPOT_DIRECTION)
	i(GL_AMBIENT_AND_DIFFUSE)
	i(GL_COLOR_INDEXES)
	i(GL_LIGHT_MODEL_TWO_SIDE)
	i(GL_LIGHT_MODEL_LOCAL_VIEWER)
	i(GL_LIGHT_MODEL_AMBIENT)
	i(GL_FRONT_AND_BACK)
	i(GL_SHADE_MODEL)
	i(GL_FLAT)
	i(GL_SMOOTH)
	i(GL_COLOR_MATERIAL)
	i(GL_COLOR_MATERIAL_FACE)
	i(GL_COLOR_MATERIAL_PARAMETER)
	i(GL_NORMALIZE)
	i(GL_CLIP_PLANE0)
	i(GL_CLIP_PLANE1)
	i(GL_CLIP_PLANE2)
	i(GL_CLIP_PLANE3)
	i(GL_CLIP_PLANE4)
	i(GL_CLIP_PLANE5)
	i(GL_ACCUM_RED_BITS)
	i(GL_ACCUM_GREEN_BITS)
	i(GL_ACCUM_BLUE_BITS)
	i(GL_ACCUM_ALPHA_BITS)
	i(GL_ACCUM_CLEAR_VALUE)
	i(GL_ACCUM)
	i(GL_ADD)
	i(GL_LOAD)
	i(GL_MULT)
	i(GL_RETURN)
	i(GL_ALPHA_TEST)
	i(GL_ALPHA_TEST_REF)
	i(GL_ALPHA_TEST_FUNC)
	i(GL_BLEND)
	i(GL_BLEND_SRC)
	i(GL_BLEND_DST)
	i(GL_ZERO)
	i(GL_ONE)
	i(GL_SRC_COLOR)
	i(GL_ONE_MINUS_SRC_COLOR)
	i(GL_DST_COLOR)
	i(GL_ONE_MINUS_DST_COLOR)
	i(GL_SRC_ALPHA)
	i(GL_ONE_MINUS_SRC_ALPHA)
	i(GL_DST_ALPHA)
	i(GL_ONE_MINUS_DST_ALPHA)
	i(GL_SRC_ALPHA_SATURATE)
		/* OS/2 PM implementation does not have these constants... */
#if !defined(GL_SRC_ALPHA_SATURATE) || defined(GL_CONSTANT_COLOR)
	i(GL_CONSTANT_COLOR)
	i(GL_ONE_MINUS_CONSTANT_COLOR)
	i(GL_CONSTANT_ALPHA)
	i(GL_ONE_MINUS_CONSTANT_ALPHA)
#endif
	i(GL_FEEDBACK)
	i(GL_RENDER)
	i(GL_SELECT)
	i(GL_2D)
	i(GL_3D)
	i(GL_3D_COLOR)
	i(GL_3D_COLOR_TEXTURE)
	i(GL_4D_COLOR_TEXTURE)
	i(GL_POINT_TOKEN)
	i(GL_LINE_TOKEN)
	i(GL_LINE_RESET_TOKEN)
	i(GL_POLYGON_TOKEN)
	i(GL_BITMAP_TOKEN)
	i(GL_DRAW_PIXEL_TOKEN)
	i(GL_COPY_PIXEL_TOKEN)
	i(GL_PASS_THROUGH_TOKEN)
	i(GL_FEEDBACK_BUFFER_SIZE)
	i(GL_FEEDBACK_BUFFER_TYPE)
	i(GL_FOG)
	i(GL_FOG_MODE)
	i(GL_FOG_DENSITY)
	i(GL_FOG_COLOR)
	i(GL_FOG_INDEX)
	i(GL_FOG_START)
	i(GL_FOG_END)
	i(GL_LINEAR)
	i(GL_EXP)
	i(GL_EXP2)
	i(GL_LOGIC_OP)
	i(GL_LOGIC_OP_MODE)
	i(GL_CLEAR)
	i(GL_SET)
	i(GL_COPY)
	i(GL_COPY_INVERTED)
	i(GL_NOOP)
	i(GL_INVERT)
	i(GL_AND)
	i(GL_NAND)
	i(GL_OR)
	i(GL_NOR)
	i(GL_XOR)
	i(GL_EQUIV)
	i(GL_AND_REVERSE)
	i(GL_AND_INVERTED)
	i(GL_OR_REVERSE)
	i(GL_OR_INVERTED)
	i(GL_STENCIL_TEST)
	i(GL_STENCIL_WRITEMASK)
	i(GL_STENCIL_BITS)
	i(GL_STENCIL_FUNC)
	i(GL_STENCIL_VALUE_MASK)
	i(GL_STENCIL_REF)
	i(GL_STENCIL_FAIL)
	i(GL_STENCIL_PASS_DEPTH_PASS)
	i(GL_STENCIL_PASS_DEPTH_FAIL)
	i(GL_STENCIL_CLEAR_VALUE)
	i(GL_STENCIL_INDEX)
	i(GL_KEEP)
	i(GL_REPLACE)
	i(GL_INCR)
	i(GL_DECR)
	i(GL_NONE)
	i(GL_LEFT)
	i(GL_RIGHT)
	i(GL_FRONT)
	i(GL_BACK)
	i(GL_FRONT_AND_BACK)
	i(GL_FRONT_LEFT)
	i(GL_FRONT_RIGHT)
	i(GL_BACK_LEFT)
	i(GL_BACK_RIGHT)
	i(GL_AUX0)
	i(GL_AUX1)
	i(GL_AUX2)
	i(GL_AUX3)
	i(GL_COLOR_INDEX)
	i(GL_RED)
	i(GL_GREEN)
	i(GL_BLUE)
	i(GL_ALPHA)
	i(GL_LUMINANCE)
	i(GL_LUMINANCE_ALPHA)
	i(GL_ALPHA_BITS)
	i(GL_RED_BITS)
	i(GL_GREEN_BITS)
	i(GL_BLUE_BITS)
	i(GL_INDEX_BITS)
	i(GL_SUBPIXEL_BITS)
	i(GL_AUX_BUFFERS)
	i(GL_READ_BUFFER)
	i(GL_DRAW_BUFFER)
	i(GL_DOUBLEBUFFER)
	i(GL_STEREO)
	i(GL_BITMAP)
	i(GL_COLOR)
	i(GL_DEPTH)
	i(GL_STENCIL)
	i(GL_DITHER)
	i(GL_RGB)
	i(GL_RGBA)
	i(GL_MAX_LIST_NESTING)
	i(GL_MAX_ATTRIB_STACK_DEPTH)
	i(GL_MAX_MODELVIEW_STACK_DEPTH)
	i(GL_MAX_NAME_STACK_DEPTH)
	i(GL_MAX_PROJECTION_STACK_DEPTH)
	i(GL_MAX_TEXTURE_STACK_DEPTH)
	i(GL_MAX_EVAL_ORDER)
	i(GL_MAX_LIGHTS)
	i(GL_MAX_CLIP_PLANES)
	i(GL_MAX_TEXTURE_SIZE)
	i(GL_MAX_PIXEL_MAP_TABLE)
	i(GL_MAX_VIEWPORT_DIMS)
	i(GL_ATTRIB_STACK_DEPTH)
	i(GL_CLIENT_ATTRIB_STACK_DEPTH)
	i(GL_COLOR_CLEAR_VALUE)
	i(GL_COLOR_WRITEMASK)
	i(GL_CURRENT_INDEX)
	i(GL_CURRENT_COLOR)
	i(GL_CURRENT_NORMAL)
	i(GL_CURRENT_RASTER_COLOR)
	i(GL_CURRENT_RASTER_DISTANCE)
	i(GL_CURRENT_RASTER_INDEX)
	i(GL_CURRENT_RASTER_POSITION)
	i(GL_CURRENT_RASTER_TEXTURE_COORDS)
	i(GL_CURRENT_RASTER_POSITION_VALID)
	i(GL_CURRENT_TEXTURE_COORDS)
	i(GL_INDEX_CLEAR_VALUE)
	i(GL_INDEX_MODE)
	i(GL_INDEX_WRITEMASK)
	i(GL_MODELVIEW_MATRIX)
	i(GL_MODELVIEW_STACK_DEPTH)
	i(GL_NAME_STACK_DEPTH)
	i(GL_PROJECTION_MATRIX)
	i(GL_PROJECTION_STACK_DEPTH)
	i(GL_RENDER_MODE)
	i(GL_RGBA_MODE)
	i(GL_TEXTURE_MATRIX)
	i(GL_TEXTURE_STACK_DEPTH)
	i(GL_VIEWPORT)
	i(GL_AUTO_NORMAL)
	i(GL_MAP1_COLOR_4)
	i(GL_MAP1_GRID_DOMAIN)
	i(GL_MAP1_GRID_SEGMENTS)
	i(GL_MAP1_INDEX)
	i(GL_MAP1_NORMAL)
	i(GL_MAP1_TEXTURE_COORD_1)
	i(GL_MAP1_TEXTURE_COORD_2)
	i(GL_MAP1_TEXTURE_COORD_3)
	i(GL_MAP1_TEXTURE_COORD_4)
	i(GL_MAP1_VERTEX_3)
	i(GL_MAP1_VERTEX_4)
	i(GL_MAP2_COLOR_4)
	i(GL_MAP2_GRID_DOMAIN)
	i(GL_MAP2_GRID_SEGMENTS)
	i(GL_MAP2_INDEX)
	i(GL_MAP2_NORMAL)
	i(GL_MAP2_TEXTURE_COORD_1)
	i(GL_MAP2_TEXTURE_COORD_2)
	i(GL_MAP2_TEXTURE_COORD_3)
	i(GL_MAP2_TEXTURE_COORD_4)
	i(GL_MAP2_VERTEX_3)
	i(GL_MAP2_VERTEX_4)
	i(GL_COEFF)
	i(GL_DOMAIN)
	i(GL_ORDER)
	i(GL_FOG_HINT)
	i(GL_LINE_SMOOTH_HINT)
	i(GL_PERSPECTIVE_CORRECTION_HINT)
	i(GL_POINT_SMOOTH_HINT)
	i(GL_POLYGON_SMOOTH_HINT)
	i(GL_DONT_CARE)
	i(GL_FASTEST)
	i(GL_NICEST)
	i(GL_SCISSOR_TEST)
	i(GL_SCISSOR_BOX)
	i(GL_MAP_COLOR)
	i(GL_MAP_STENCIL)
	i(GL_INDEX_SHIFT)
	i(GL_INDEX_OFFSET)
	i(GL_RED_SCALE)
	i(GL_RED_BIAS)
	i(GL_GREEN_SCALE)
	i(GL_GREEN_BIAS)
	i(GL_BLUE_SCALE)
	i(GL_BLUE_BIAS)
	i(GL_ALPHA_SCALE)
	i(GL_ALPHA_BIAS)
	i(GL_DEPTH_SCALE)
	i(GL_DEPTH_BIAS)
	i(GL_PIXEL_MAP_S_TO_S_SIZE)
	i(GL_PIXEL_MAP_I_TO_I_SIZE)
	i(GL_PIXEL_MAP_I_TO_R_SIZE)
	i(GL_PIXEL_MAP_I_TO_G_SIZE)
	i(GL_PIXEL_MAP_I_TO_B_SIZE)
	i(GL_PIXEL_MAP_I_TO_A_SIZE)
	i(GL_PIXEL_MAP_R_TO_R_SIZE)
	i(GL_PIXEL_MAP_G_TO_G_SIZE)
	i(GL_PIXEL_MAP_B_TO_B_SIZE)
	i(GL_PIXEL_MAP_A_TO_A_SIZE)
	i(GL_PIXEL_MAP_S_TO_S)
	i(GL_PIXEL_MAP_I_TO_I)
	i(GL_PIXEL_MAP_I_TO_R)
	i(GL_PIXEL_MAP_I_TO_G)
	i(GL_PIXEL_MAP_I_TO_B)
	i(GL_PIXEL_MAP_I_TO_A)
	i(GL_PIXEL_MAP_R_TO_R)
	i(GL_PIXEL_MAP_G_TO_G)
	i(GL_PIXEL_MAP_B_TO_B)
	i(GL_PIXEL_MAP_A_TO_A)
	i(GL_PACK_ALIGNMENT)
	i(GL_PACK_LSB_FIRST)
	i(GL_PACK_ROW_LENGTH)
	i(GL_PACK_SKIP_PIXELS)
	i(GL_PACK_SKIP_ROWS)
	i(GL_PACK_SWAP_BYTES)
	i(GL_UNPACK_ALIGNMENT)
	i(GL_UNPACK_LSB_FIRST)
	i(GL_UNPACK_ROW_LENGTH)
	i(GL_UNPACK_SKIP_PIXELS)
	i(GL_UNPACK_SKIP_ROWS)
	i(GL_UNPACK_SWAP_BYTES)
	i(GL_ZOOM_X)
	i(GL_ZOOM_Y)
	i(GL_TEXTURE_ENV)
	i(GL_TEXTURE_ENV_MODE)
	i(GL_TEXTURE_1D)
	i(GL_TEXTURE_2D)
	i(GL_TEXTURE_WRAP_S)
	i(GL_TEXTURE_WRAP_T)
	i(GL_TEXTURE_MAG_FILTER)
	i(GL_TEXTURE_MIN_FILTER)
	i(GL_TEXTURE_ENV_COLOR)
	i(GL_TEXTURE_GEN_S)
	i(GL_TEXTURE_GEN_T)
	i(GL_TEXTURE_GEN_MODE)
	i(GL_TEXTURE_BORDER_COLOR)
	i(GL_TEXTURE_WIDTH)
	i(GL_TEXTURE_HEIGHT)
	i(GL_TEXTURE_BORDER)
	i(GL_TEXTURE_COMPONENTS)
	i(GL_TEXTURE_RED_SIZE)
	i(GL_TEXTURE_GREEN_SIZE)
	i(GL_TEXTURE_BLUE_SIZE)
	i(GL_TEXTURE_ALPHA_SIZE)
	i(GL_TEXTURE_LUMINANCE_SIZE)
	i(GL_TEXTURE_INTENSITY_SIZE)
	i(GL_NEAREST_MIPMAP_NEAREST)
	i(GL_NEAREST_MIPMAP_LINEAR)
	i(GL_LINEAR_MIPMAP_NEAREST)
	i(GL_LINEAR_MIPMAP_LINEAR)
	i(GL_OBJECT_LINEAR)
	i(GL_OBJECT_PLANE)
	i(GL_EYE_LINEAR)
	i(GL_EYE_PLANE)
	i(GL_SPHERE_MAP)
	i(GL_DECAL)
	i(GL_MODULATE)
	i(GL_NEAREST)
	i(GL_REPEAT)
	i(GL_CLAMP)
	i(GL_S)
	i(GL_T)
	i(GL_R)
	i(GL_Q)
	i(GL_TEXTURE_GEN_R)
	i(GL_TEXTURE_GEN_Q)
	i(GL_VENDOR)
	i(GL_RENDERER)
	i(GL_VERSION)
	i(GL_EXTENSIONS)
	i(GL_INVALID_VALUE)
	i(GL_INVALID_ENUM)
	i(GL_INVALID_OPERATION)
	i(GL_STACK_OVERFLOW)
	i(GL_STACK_UNDERFLOW)
	i(GL_OUT_OF_MEMORY)

#ifdef GL_VERSION_1_1
	i(GL_TEXTURE_RESIDENT)
	i(GL_TEXTURE_BINDING_1D)
	i(GL_TEXTURE_BINDING_2D)
	i(GL_TEXTURE_PRIORITY)
	i(GL_PROXY_TEXTURE_1D)
	i(GL_PROXY_TEXTURE_2D)
	i(GL_FEEDBACK_BUFFER_POINTER)
	i(GL_VERTEX_ARRAY)
	i(GL_NORMAL_ARRAY)
	i(GL_COLOR_ARRAY)
	i(GL_INDEX_ARRAY)
	i(GL_TEXTURE_COORD_ARRAY)
	i(GL_EDGE_FLAG_ARRAY)
	i(GL_VERTEX_ARRAY_SIZE)
	i(GL_VERTEX_ARRAY_TYPE)
	i(GL_VERTEX_ARRAY_STRIDE)
	i(GL_NORMAL_ARRAY_TYPE)
	i(GL_NORMAL_ARRAY_STRIDE)
	i(GL_COLOR_ARRAY_SIZE)
	i(GL_COLOR_ARRAY_TYPE)
	i(GL_COLOR_ARRAY_STRIDE)
	i(GL_INDEX_ARRAY_TYPE)
	i(GL_INDEX_ARRAY_STRIDE)
	i(GL_TEXTURE_COORD_ARRAY_SIZE)
	i(GL_TEXTURE_COORD_ARRAY_TYPE)
	i(GL_TEXTURE_COORD_ARRAY_STRIDE)
	i(GL_EDGE_FLAG_ARRAY_STRIDE)
	i(GL_VERTEX_ARRAY_POINTER)
	i(GL_NORMAL_ARRAY_POINTER)
	i(GL_COLOR_ARRAY_POINTER)
	i(GL_INDEX_ARRAY_POINTER)
	i(GL_TEXTURE_COORD_ARRAY_POINTER)
	i(GL_EDGE_FLAG_ARRAY_POINTER)
	i(GL_POLYGON_OFFSET_FACTOR)
	i(GL_POLYGON_OFFSET_UNITS)
	i(GL_POLYGON_OFFSET_POINT)
	i(GL_POLYGON_OFFSET_LINE)
	i(GL_POLYGON_OFFSET_FILL)
	i(GL_INDEX_LOGIC_OP)
	i(GL_COLOR_LOGIC_OP)
	i(GL_ALPHA4)
	i(GL_ALPHA8)
	i(GL_ALPHA12)
	i(GL_ALPHA16)
	i(GL_LUMINANCE4)
	i(GL_LUMINANCE8)
	i(GL_LUMINANCE12)
	i(GL_LUMINANCE16)
	i(GL_LUMINANCE4_ALPHA4)
	i(GL_LUMINANCE6_ALPHA2)
	i(GL_LUMINANCE8_ALPHA8)
	i(GL_LUMINANCE12_ALPHA4)
	i(GL_LUMINANCE12_ALPHA12)
	i(GL_LUMINANCE16_ALPHA16)
	i(GL_INTENSITY)
	i(GL_INTENSITY4)
	i(GL_INTENSITY8)
	i(GL_INTENSITY12)
	i(GL_INTENSITY16)
	i(GL_R3_G3_B2)
	i(GL_RGB4)
	i(GL_RGB5)
	i(GL_RGB8)
	i(GL_RGB10)
	i(GL_RGB12)
	i(GL_RGB16)
	i(GL_RGBA2)
	i(GL_RGBA4)
	i(GL_RGB5_A1)
	i(GL_RGBA8)
	i(GL_RGB10_A2)
	i(GL_RGBA12)
	i(GL_RGBA16)
#endif

#ifdef GL_VERSION_1_2

/* ADDED in 0.55 */

#ifndef GL_R3_G3_B2_EXT
#define GL_R3_G3_B2_EXT GL_R3_G3_B2
#endif

#ifndef GL_MISC_BIT_EXT
#define GL_MISC_BIT_EXT 0
#endif

#ifndef GL_COLOR_TABLE_FORMAT_EXT
#define GL_COLOR_TABLE_FORMAT_EXT GL_COLOR_TABLE_FORMAT
#endif

#ifndef GL_COLOR_TABLE_WIDTH_EXT
#define GL_COLOR_TABLE_WIDTH_EXT GL_COLOR_TABLE_WIDTH
#endif

#ifndef GL_COLOR_TABLE_RED_SIZE_EXT
#define GL_COLOR_TABLE_RED_SIZE_EXT GL_COLOR_TABLE_RED_SIZE
#endif

#ifndef GL_COLOR_TABLE_GREEN_SIZE_EXT
#define GL_COLOR_TABLE_GREEN_SIZE_EXT GL_COLOR_TABLE_GREEN_SIZE
#endif

#ifndef GL_COLOR_TABLE_BLUE_SIZE_EXT
#define GL_COLOR_TABLE_BLUE_SIZE_EXT GL_COLOR_TABLE_BLUE_SIZE
#endif

#ifndef GL_COLOR_TABLE_ALPHA_SIZE_EXT
#define GL_COLOR_TABLE_ALPHA_SIZE_EXT GL_COLOR_TABLE_ALPHA_SIZE
#endif

#ifndef GL_COLOR_TABLE_LUMINANCE_SIZE_EXT
#define GL_COLOR_TABLE_LUMINANCE_SIZE_EXT GL_COLOR_TABLE_LUMINANCE_SIZE
#endif

#ifndef GL_COLOR_TABLE_INTENSITY_SIZE_EXT
#define GL_COLOR_TABLE_INTENSITY_SIZE_EXT GL_COLOR_TABLE_INTENSITY_SIZE
#endif

/* Texture3D */
	i(GL_PACK_SKIP_IMAGES)
	i(GL_PACK_IMAGE_HEIGHT)
	i(GL_UNPACK_SKIP_IMAGES)
	i(GL_UNPACK_IMAGE_HEIGHT)
	i(GL_TEXTURE_3D)
	i(GL_PROXY_TEXTURE_3D)
	i(GL_TEXTURE_DEPTH)
	i(GL_TEXTURE_WRAP_R)
	i(GL_MAX_3D_TEXTURE_SIZE)
	i(GL_TEXTURE_BINDING_3D)

/* BGR */
	i(GL_BGR)
	i(GL_BGRA)

/* Packed pixels */
	i(GL_UNSIGNED_BYTE_3_3_2)
	i(GL_UNSIGNED_BYTE_2_3_3_REV)
	i(GL_UNSIGNED_SHORT_5_6_5)
	i(GL_UNSIGNED_SHORT_5_6_5_REV)
	i(GL_UNSIGNED_SHORT_4_4_4_4)
	i(GL_UNSIGNED_SHORT_4_4_4_4_REV)
	i(GL_UNSIGNED_SHORT_5_5_5_1)
	i(GL_UNSIGNED_SHORT_1_5_5_5_REV)
	i(GL_UNSIGNED_INT_8_8_8_8)
	i(GL_UNSIGNED_INT_8_8_8_8_REV)
	i(GL_UNSIGNED_INT_10_10_10_2)
	i(GL_UNSIGNED_INT_2_10_10_10_REV)

/* Rescale normals */
	i(GL_RESCALE_NORMAL)

/* Separate specular color */
	i(GL_LIGHT_MODEL_COLOR_CONTROL)
	i(GL_SINGLE_COLOR)
	i(GL_SEPARATE_SPECULAR_COLOR)

/* texture_edge_clamp */
	i(GL_CLAMP_TO_EDGE)

/* texture_lod */
	i(GL_TEXTURE_MIN_LOD)
	i(GL_TEXTURE_MAX_LOD)
	i(GL_TEXTURE_BASE_LEVEL)
	i(GL_TEXTURE_MAX_LEVEL)

/* draw_range_elements*/
	i(GL_MAX_ELEMENTS_VERTICES)
	i(GL_MAX_ELEMENTS_INDICES)



/* ADDED in 0.55 */

/* ErrorCode */
	i(GL_NO_ERROR)

/* GetTarget */
	i(GL_MAX_CLIENT_ATTRIB_STACK_DEPTH)
	i(GL_SELECTION_BUFFER_POINTER)
	i(GL_SELECTION_BUFFER_SIZE)

/* GetTextureParameter */
	i(GL_TEXTURE_INTERNAL_FORMAT)

/* blend_color */
	i(GL_BLEND_COLOR)

/* blend_minmax */
	i(GL_FUNC_ADD)
	i(GL_MIN)
	i(GL_MAX)
	i(GL_BLEND_EQUATION)

/* blend_subtract */
	i(GL_FUNC_SUBTRACT)
	i(GL_FUNC_REVERSE_SUBTRACT)

/* color_matrix */
	i(GL_COLOR_MATRIX)
	i(GL_COLOR_MATRIX_STACK_DEPTH)
	i(GL_MAX_COLOR_MATRIX_STACK_DEPTH)
	i(GL_POST_COLOR_MATRIX_RED_SCALE)
	i(GL_POST_COLOR_MATRIX_GREEN_SCALE)
	i(GL_POST_COLOR_MATRIX_BLUE_SCALE)
	i(GL_POST_COLOR_MATRIX_ALPHA_SCALE)
	i(GL_POST_COLOR_MATRIX_RED_BIAS)
	i(GL_POST_COLOR_MATRIX_GREEN_BIAS)
	i(GL_POST_COLOR_MATRIX_BLUE_BIAS)
	i(GL_POST_COLOR_MATRIX_ALPHA_BIAS)

/* color_table */
	i(GL_COLOR_TABLE)
	i(GL_POST_CONVOLUTION_COLOR_TABLE)
	i(GL_POST_COLOR_MATRIX_COLOR_TABLE)
	i(GL_PROXY_COLOR_TABLE)
	i(GL_PROXY_POST_CONVOLUTION_COLOR_TABLE)
	i(GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE)
	i(GL_COLOR_TABLE_SCALE)
	i(GL_COLOR_TABLE_BIAS)
	i(GL_COLOR_TABLE_FORMAT)
	i(GL_COLOR_TABLE_WIDTH)
	i(GL_COLOR_TABLE_RED_SIZE)
	i(GL_COLOR_TABLE_GREEN_SIZE)
	i(GL_COLOR_TABLE_BLUE_SIZE)
	i(GL_COLOR_TABLE_ALPHA_SIZE)
	i(GL_COLOR_TABLE_LUMINANCE_SIZE)
	i(GL_COLOR_TABLE_INTENSITY_SIZE)

/* convolution */
	i(GL_CONVOLUTION_1D)
	i(GL_CONVOLUTION_2D)
	i(GL_SEPARABLE_2D)
	i(GL_CONVOLUTION_BORDER_MODE)
	i(GL_CONVOLUTION_FILTER_SCALE)
	i(GL_CONVOLUTION_FILTER_BIAS)
	i(GL_REDUCE)
	i(GL_CONVOLUTION_FORMAT)
	i(GL_CONVOLUTION_WIDTH)
	i(GL_CONVOLUTION_HEIGHT)
	i(GL_MAX_CONVOLUTION_WIDTH)
	i(GL_MAX_CONVOLUTION_HEIGHT)
	i(GL_POST_CONVOLUTION_RED_SCALE)
	i(GL_POST_CONVOLUTION_GREEN_SCALE)
	i(GL_POST_CONVOLUTION_BLUE_SCALE)
	i(GL_POST_CONVOLUTION_ALPHA_SCALE)
	i(GL_POST_CONVOLUTION_RED_BIAS)
	i(GL_POST_CONVOLUTION_GREEN_BIAS)
	i(GL_POST_CONVOLUTION_BLUE_BIAS)
	i(GL_POST_CONVOLUTION_ALPHA_BIAS)
	i(GL_CONSTANT_BORDER)
	i(GL_REPLICATE_BORDER)
	i(GL_CONVOLUTION_BORDER_COLOR)

/* histogram */
	i(GL_HISTOGRAM)
	i(GL_PROXY_HISTOGRAM)
	i(GL_HISTOGRAM_WIDTH)
	i(GL_HISTOGRAM_FORMAT)
	i(GL_HISTOGRAM_RED_SIZE)
	i(GL_HISTOGRAM_GREEN_SIZE)
	i(GL_HISTOGRAM_BLUE_SIZE)
	i(GL_HISTOGRAM_ALPHA_SIZE)
	i(GL_HISTOGRAM_LUMINANCE_SIZE)
	i(GL_HISTOGRAM_SINK)
	i(GL_MINMAX)
	i(GL_MINMAX_FORMAT)
	i(GL_MINMAX_SINK)
	i(GL_TABLE_TOO_LARGE)

/* GetTarget1_2 */
	i(GL_SMOOTH_POINT_SIZE_RANGE)
	i(GL_SMOOTH_POINT_SIZE_GRANULARITY)
	i(GL_SMOOTH_LINE_WIDTH_RANGE)
	i(GL_SMOOTH_LINE_WIDTH_GRANULARITY)
	i(GL_ALIASED_POINT_SIZE_RANGE)
	i(GL_ALIASED_LINE_WIDTH_RANGE)

/* multitexture */
	i(GL_TEXTURE0_ARB)
	i(GL_TEXTURE1_ARB)
	i(GL_TEXTURE2_ARB)
	i(GL_TEXTURE3_ARB)
	i(GL_TEXTURE4_ARB)
	i(GL_TEXTURE5_ARB)
	i(GL_TEXTURE6_ARB)
	i(GL_TEXTURE7_ARB)
	i(GL_TEXTURE8_ARB)
	i(GL_TEXTURE9_ARB)
	i(GL_TEXTURE10_ARB)
	i(GL_TEXTURE11_ARB)
	i(GL_TEXTURE12_ARB)
	i(GL_TEXTURE13_ARB)
	i(GL_TEXTURE14_ARB)
	i(GL_TEXTURE15_ARB)
	i(GL_TEXTURE16_ARB)
	i(GL_TEXTURE17_ARB)
	i(GL_TEXTURE18_ARB)
	i(GL_TEXTURE19_ARB)
	i(GL_TEXTURE20_ARB)
	i(GL_TEXTURE21_ARB)
	i(GL_TEXTURE22_ARB)
	i(GL_TEXTURE23_ARB)
	i(GL_TEXTURE24_ARB)
	i(GL_TEXTURE25_ARB)
	i(GL_TEXTURE26_ARB)
	i(GL_TEXTURE27_ARB)
	i(GL_TEXTURE28_ARB)
	i(GL_TEXTURE29_ARB)
	i(GL_TEXTURE30_ARB)
	i(GL_TEXTURE31_ARB)
	i(GL_ACTIVE_TEXTURE_ARB)
	i(GL_CLIENT_ACTIVE_TEXTURE_ARB)
	i(GL_MAX_TEXTURE_UNITS_ARB)
#endif

/* 2, see 37 */

/* 3 */
#if defined(GL_EXT_polygon_offset)
	i(GL_POLYGON_OFFSET_EXT)
	i(GL_POLYGON_OFFSET_FACTOR_EXT)
	i(GL_POLYGON_OFFSET_BIAS_EXT)
#endif

/* 4 */
#ifdef GL_EXT_texture
	i(GL_ALPHA4_EXT)
	i(GL_ALPHA8_EXT)
	i(GL_ALPHA12_EXT)
	i(GL_ALPHA16_EXT)
	i(GL_LUMINANCE4_EXT)
	i(GL_LUMINANCE8_EXT)
	i(GL_LUMINANCE12_EXT)
	i(GL_LUMINANCE16_EXT)
	i(GL_LUMINANCE4_ALPHA4_EXT)
	i(GL_LUMINANCE6_ALPHA2_EXT)
	i(GL_LUMINANCE8_ALPHA8_EXT)
	i(GL_LUMINANCE12_ALPHA4_EXT)
	i(GL_LUMINANCE12_ALPHA12_EXT)
	i(GL_LUMINANCE16_ALPHA16_EXT)
	i(GL_INTENSITY_EXT)
	i(GL_INTENSITY4_EXT)
	i(GL_INTENSITY8_EXT)
	i(GL_INTENSITY12_EXT)
	i(GL_INTENSITY16_EXT)
	i(GL_R3_G3_B2_EXT)
	i(GL_RGB4_EXT)
	i(GL_RGB5_EXT)
	i(GL_RGB8_EXT)
	i(GL_RGB10_EXT)
	i(GL_RGB12_EXT)
	i(GL_RGB16_EXT)
	i(GL_RGBA2_EXT)
	i(GL_RGBA4_EXT)
	i(GL_RGB5_A1_EXT)
	i(GL_RGBA8_EXT)
	i(GL_RGB10_A2_EXT)
	i(GL_RGBA12_EXT)
	i(GL_RGBA16_EXT)

	i(GL_TEXTURE_RED_SIZE_EXT)
	i(GL_TEXTURE_GREEN_SIZE_EXT)
	i(GL_TEXTURE_BLUE_SIZE_EXT)
	i(GL_TEXTURE_ALPHA_SIZE_EXT)
	i(GL_TEXTURE_LUMINANCE_SIZE_EXT)
	i(GL_TEXTURE_INTENSITY_SIZE_EXT)

	i(GL_REPLACE_EXT)

	i(GL_PROXY_TEXTURE_1D)
	i(GL_PROXY_TEXTURE_2D)

	i(GL_TEXTURE_TOO_LARGE_EXT)

#endif

/* 18 */
#ifdef GL_EXT_cmyka
	i(GL_CMYK_EXT)
	i(GL_CMYKA_EXT)
	i(GL_PACK_CMYK_HINT_EXT)
	i(GL_UNPACK_CMYK_HINT_EXT)
	i(GL_CMYK)
	i(GL_CMYKA)
	i(GL_PACK_CMYK_HINT)
	i(GL_UNPACK_CMYK_HINT)
#endif

/* 20 */
#ifdef GL_EXT_texture_object
	i(GL_TEXTURE_PRIORITY_EXT)
	i(GL_TEXTURE_RESIDENT_EXT)
	i(GL_TEXTURE_1D_BINDING_EXT)
	i(GL_TEXTURE_2D_BINDING_EXT)
#  ifdef GL_TEXTURE_3D_BINDING_EXT /* GL_EXT_texture3D - A hack for Solaris */
	i(GL_TEXTURE_3D_BINDING_EXT)
#  endif
#endif

/* 30 */
#if defined(GL_EXT_vertex_array)
	i(GL_VERTEX_ARRAY_EXT)
	i(GL_NORMAL_ARRAY_EXT)
	i(GL_COLOR_ARRAY_EXT)
	i(GL_INDEX_ARRAY_EXT)
	i(GL_TEXTURE_COORD_ARRAY_EXT)
	i(GL_EDGE_FLAG_ARRAY_EXT)

	i(GL_VERTEX_ARRAY_SIZE_EXT)
	i(GL_VERTEX_ARRAY_TYPE_EXT)
	i(GL_VERTEX_ARRAY_STRIDE_EXT)
	i(GL_NORMAL_ARRAY_TYPE_EXT)
	i(GL_NORMAL_ARRAY_STRIDE_EXT)
	i(GL_COLOR_ARRAY_SIZE_EXT)
	i(GL_COLOR_ARRAY_TYPE_EXT)
	i(GL_COLOR_ARRAY_STRIDE_EXT)
	i(GL_INDEX_ARRAY_TYPE_EXT)
	i(GL_INDEX_ARRAY_STRIDE_EXT)
	i(GL_TEXTURE_COORD_ARRAY_SIZE_EXT)
	i(GL_TEXTURE_COORD_ARRAY_TYPE_EXT)
	i(GL_TEXTURE_COORD_ARRAY_STRIDE_EXT)
	i(GL_EDGE_FLAG_ARRAY_STRIDE_EXT)
	i(GL_VERTEX_ARRAY_POINTER_EXT)
	i(GL_NORMAL_ARRAY_POINTER_EXT)
	i(GL_COLOR_ARRAY_POINTER_EXT)
	i(GL_INDEX_ARRAY_POINTER_EXT)
	i(GL_TEXTURE_COORD_ARRAY_POINTER_EXT)
	i(GL_EDGE_FLAG_ARRAY_POINTER_EXT)
#  ifndef GL_EXT_vertex_array_is_faked
	i(GL_VERTEX_ARRAY_COUNT_EXT)
	i(GL_NORMAL_ARRAY_COUNT_EXT)
	i(GL_COLOR_ARRAY_COUNT_EXT)
	i(GL_INDEX_ARRAY_COUNT_EXT)
	i(GL_TEXTURE_COORD_ARRAY_COUNT_EXT)
	i(GL_EDGE_FLAG_ARRAY_COUNT_EXT)
#  endif
#endif

/* 31 */
#ifdef GL_EXT_misc_attribute
	i(GL_MISC_BIT_EXT)
#endif

/* 37 & 2 */
#if defined(GL_EXT_blend_minmax) || defined(GL_EXT_blend_color)
	i(GL_CONSTANT_COLOR_EXT)
	i(GL_ONE_MINUS_CONSTANT_COLOR_EXT)
	i(GL_CONSTANT_ALPHA_EXT)
	i(GL_ONE_MINUS_CONSTANT_ALPHA_EXT)
	i(GL_BLEND_EQUATION_EXT)
	i(GL_MIN_EXT)
	i(GL_MAX_EXT)
	i(GL_FUNC_ADD_EXT)
	i(GL_FUNC_SUBTRACT_EXT)
	i(GL_FUNC_REVERSE_SUBTRACT_EXT)
	i(GL_BLEND_COLOR_EXT)
#endif

/* 44 */
#ifdef GL_EXT_abgr
	i(GL_ABGR_EXT)
#endif

/* 79 */
#if defined(GL_EXT_clip_volume_hint) && defined(GL_VOLUME_CLIPPING_HINT_EXT)
	i(GL_VOLUME_CLIPPING_HINT_EXT)
#endif

#if defined(GL_EXT_texture_priority)
	i(GL_TEXTURE_PRIORITY_EXT)
	i(GL_TEXTURE_RESIDENT_EXT)
	i(GL_TEXTURE_1D_BINDING_EXT)
	i(GL_TEXTURE_2D_BINDING_EXT)
#endif

#if defined(GL_EXT_texture3D)
	i(GL_PACK_SKIP_IMAGES_EXT)
	i(GL_PACK_IMAGE_HEIGHT_EXT)
	i(GL_UNPACK_SKIP_IMAGES_EXT)
	i(GL_UNPACK_IMAGE_HEIGHT_EXT)
	i(GL_TEXTURE_3D_EXT)
	i(GL_PROXY_TEXTURE_3D_EXT)
	i(GL_TEXTURE_DEPTH_EXT)
	i(GL_TEXTURE_WRAP_R_EXT)
	i(GL_MAX_3D_TEXTURE_SIZE_EXT)
#  ifdef GL_TEXTURE_3D_BINDING_EXT /* GL_EXT_texture3D - A hack for Solaris */
	i(GL_TEXTURE_3D_BINDING_EXT)
#  endif
#endif

#if defined(GL_EXT_paletted_texture)
	i(GL_TABLE_TOO_LARGE_EXT)
	i(GL_COLOR_TABLE_FORMAT_EXT)
	i(GL_COLOR_TABLE_WIDTH_EXT)
	i(GL_COLOR_TABLE_RED_SIZE_EXT)
	i(GL_COLOR_TABLE_GREEN_SIZE_EXT)
	i(GL_COLOR_TABLE_BLUE_SIZE_EXT)
	i(GL_COLOR_TABLE_ALPHA_SIZE_EXT)
	i(GL_COLOR_TABLE_LUMINANCE_SIZE_EXT)
	i(GL_COLOR_TABLE_INTENSITY_SIZE_EXT)
	i(GL_TEXTURE_INDEX_SIZE_EXT)
	i(GL_COLOR_INDEX1_EXT)
	i(GL_COLOR_INDEX2_EXT)
	i(GL_COLOR_INDEX4_EXT)
	i(GL_COLOR_INDEX8_EXT)
	i(GL_COLOR_INDEX12_EXT)
	i(GL_COLOR_INDEX16_EXT)
#endif

#if defined(GL_EXT_shared_texture_palette)
	i(GL_SHARED_TEXTURE_PALETTE_EXT)
#endif

#if defined(GL_EXT_point_parameters)
	i(GL_POINT_SIZE_MIN_EXT)
	i(GL_POINT_SIZE_MAX_EXT)
	i(GL_POINT_FADE_THRESHOLD_SIZE_EXT)
	i(GL_DISTANCE_ATTENUATION_EXT)
#endif

#if defined(GL_EXT_Cg_shader)
	i(GL_CG_VERTEX_SHADER_EXT)
	i(GL_CG_FRAGMENT_SHADER_EXT)
#endif

/* ADDED in 0.55 */
#if defined(GL_EXT_texture_env_combine)
	i(GL_COMBINE_EXT)
	i(GL_COMBINE_RGB_EXT)
	i(GL_COMBINE_ALPHA_EXT)
	i(GL_RGB_SCALE_EXT)
	i(GL_ADD_SIGNED_EXT)
	i(GL_INTERPOLATE_EXT)
	i(GL_CONSTANT_EXT)
	i(GL_PRIMARY_COLOR_EXT)
	i(GL_PREVIOUS_EXT)
	i(GL_SOURCE0_RGB_EXT)
	i(GL_SOURCE1_RGB_EXT)
	i(GL_SOURCE2_RGB_EXT)
	i(GL_SOURCE0_ALPHA_EXT)
	i(GL_SOURCE1_ALPHA_EXT)
	i(GL_SOURCE2_ALPHA_EXT)
	i(GL_OPERAND0_RGB_EXT)
	i(GL_OPERAND1_RGB_EXT)
	i(GL_OPERAND2_RGB_EXT)
	i(GL_OPERAND0_ALPHA_EXT)
	i(GL_OPERAND1_ALPHA_EXT)
	i(GL_OPERAND2_ALPHA_EXT)
#endif

/* FROM glext_procs.h */
#if defined(__glext_procs_h_)
	i(GL_GLEXT_VERSION)
	i(GL_SMOOTH_POINT_SIZE_RANGE)
	i(GL_SMOOTH_POINT_SIZE_GRANULARITY)
	i(GL_SMOOTH_LINE_WIDTH_RANGE)
	i(GL_SMOOTH_LINE_WIDTH_GRANULARITY)
	i(GL_ALIASED_POINT_SIZE_RANGE)
	i(GL_ALIASED_LINE_WIDTH_RANGE)
	i(GL_BLEND_COLOR)
	i(GL_FUNC_ADD)
	i(GL_MIN)
	i(GL_MAX)
	i(GL_BLEND_EQUATION)
	i(GL_FUNC_SUBTRACT)
	i(GL_FUNC_REVERSE_SUBTRACT)
	i(GL_CONVOLUTION_1D)
	i(GL_CONVOLUTION_2D)
	i(GL_SEPARABLE_2D)
	i(GL_CONVOLUTION_BORDER_MODE)
	i(GL_CONVOLUTION_FILTER_SCALE)
	i(GL_CONVOLUTION_FILTER_BIAS)
	i(GL_REDUCE)
	i(GL_CONVOLUTION_FORMAT)
	i(GL_CONVOLUTION_WIDTH)
	i(GL_CONVOLUTION_HEIGHT)
	i(GL_MAX_CONVOLUTION_WIDTH)
	i(GL_MAX_CONVOLUTION_HEIGHT)
	i(GL_POST_CONVOLUTION_RED_SCALE)
	i(GL_POST_CONVOLUTION_GREEN_SCALE)
	i(GL_POST_CONVOLUTION_BLUE_SCALE)
	i(GL_POST_CONVOLUTION_ALPHA_SCALE)
	i(GL_POST_CONVOLUTION_RED_BIAS)
	i(GL_POST_CONVOLUTION_GREEN_BIAS)
	i(GL_POST_CONVOLUTION_BLUE_BIAS)
	i(GL_POST_CONVOLUTION_ALPHA_BIAS)
	i(GL_HISTOGRAM)
	i(GL_PROXY_HISTOGRAM)
	i(GL_HISTOGRAM_WIDTH)
	i(GL_HISTOGRAM_FORMAT)
	i(GL_HISTOGRAM_RED_SIZE)
	i(GL_HISTOGRAM_GREEN_SIZE)
	i(GL_HISTOGRAM_BLUE_SIZE)
	i(GL_HISTOGRAM_ALPHA_SIZE)
	i(GL_HISTOGRAM_LUMINANCE_SIZE)
	i(GL_HISTOGRAM_SINK)
	i(GL_MINMAX)
	i(GL_MINMAX_FORMAT)
	i(GL_MINMAX_SINK)
	i(GL_TABLE_TOO_LARGE)
	i(GL_COLOR_MATRIX)
	i(GL_COLOR_MATRIX_STACK_DEPTH)
	i(GL_MAX_COLOR_MATRIX_STACK_DEPTH)
	i(GL_POST_COLOR_MATRIX_RED_SCALE)
	i(GL_POST_COLOR_MATRIX_GREEN_SCALE)
	i(GL_POST_COLOR_MATRIX_BLUE_SCALE)
	i(GL_POST_COLOR_MATRIX_ALPHA_SCALE)
	i(GL_POST_COLOR_MATRIX_RED_BIAS)
	i(GL_POST_COLOR_MATRIX_GREEN_BIAS)
	i(GL_POST_COLOR_MATRIX_BLUE_BIAS)
	i(GL_POST_COLOR_MATRIX_ALPHA_BIAS)
	i(GL_COLOR_TABLE)
	i(GL_POST_CONVOLUTION_COLOR_TABLE)
	i(GL_POST_COLOR_MATRIX_COLOR_TABLE)
	i(GL_PROXY_COLOR_TABLE)
	i(GL_PROXY_POST_CONVOLUTION_COLOR_TABLE)
	i(GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE)
	i(GL_COLOR_TABLE_SCALE)
	i(GL_COLOR_TABLE_BIAS)
	i(GL_COLOR_TABLE_FORMAT)
	i(GL_COLOR_TABLE_WIDTH)
	i(GL_COLOR_TABLE_RED_SIZE)
	i(GL_COLOR_TABLE_GREEN_SIZE)
	i(GL_COLOR_TABLE_BLUE_SIZE)
	i(GL_COLOR_TABLE_ALPHA_SIZE)
	i(GL_COLOR_TABLE_LUMINANCE_SIZE)
	i(GL_COLOR_TABLE_INTENSITY_SIZE)
	i(GL_CONSTANT_BORDER)
	i(GL_REPLICATE_BORDER)
	i(GL_CONVOLUTION_BORDER_COLOR)
	i(GL_TEXTURE0)
	i(GL_TEXTURE1)
	i(GL_TEXTURE2)
	i(GL_TEXTURE3)
	i(GL_TEXTURE4)
	i(GL_TEXTURE5)
	i(GL_TEXTURE6)
	i(GL_TEXTURE7)
	i(GL_TEXTURE8)
	i(GL_TEXTURE9)
	i(GL_TEXTURE10)
	i(GL_TEXTURE11)
	i(GL_TEXTURE12)
	i(GL_TEXTURE13)
	i(GL_TEXTURE14)
	i(GL_TEXTURE15)
	i(GL_TEXTURE16)
	i(GL_TEXTURE17)
	i(GL_TEXTURE18)
	i(GL_TEXTURE19)
	i(GL_TEXTURE20)
	i(GL_TEXTURE21)
	i(GL_TEXTURE22)
	i(GL_TEXTURE23)
	i(GL_TEXTURE24)
	i(GL_TEXTURE25)
	i(GL_TEXTURE26)
	i(GL_TEXTURE27)
	i(GL_TEXTURE28)
	i(GL_TEXTURE29)
	i(GL_TEXTURE30)
	i(GL_TEXTURE31)
	i(GL_ACTIVE_TEXTURE)
	i(GL_CLIENT_ACTIVE_TEXTURE)
	i(GL_MAX_TEXTURE_UNITS)
	i(GL_TRANSPOSE_MODELVIEW_MATRIX)
	i(GL_TRANSPOSE_PROJECTION_MATRIX)
	i(GL_TRANSPOSE_TEXTURE_MATRIX)
	i(GL_TRANSPOSE_COLOR_MATRIX)
	i(GL_MULTISAMPLE)
	i(GL_SAMPLE_ALPHA_TO_COVERAGE)
	i(GL_SAMPLE_ALPHA_TO_ONE)
	i(GL_SAMPLE_COVERAGE)
	i(GL_SAMPLE_BUFFERS)
	i(GL_SAMPLES)
	i(GL_SAMPLE_COVERAGE_VALUE)
	i(GL_SAMPLE_COVERAGE_INVERT)
	i(GL_MULTISAMPLE_BIT)
	i(GL_NORMAL_MAP)
	i(GL_REFLECTION_MAP)
	i(GL_TEXTURE_CUBE_MAP)
	i(GL_TEXTURE_BINDING_CUBE_MAP)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_X)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z)
	i(GL_PROXY_TEXTURE_CUBE_MAP)
	i(GL_MAX_CUBE_MAP_TEXTURE_SIZE)
	i(GL_COMPRESSED_ALPHA)
	i(GL_COMPRESSED_LUMINANCE)
	i(GL_COMPRESSED_LUMINANCE_ALPHA)
	i(GL_COMPRESSED_INTENSITY)
	i(GL_COMPRESSED_RGB)
	i(GL_COMPRESSED_RGBA)
	i(GL_TEXTURE_COMPRESSION_HINT)
	i(GL_TEXTURE_COMPRESSED_IMAGE_SIZE)
	i(GL_TEXTURE_COMPRESSED)
	i(GL_NUM_COMPRESSED_TEXTURE_FORMATS)
	i(GL_COMPRESSED_TEXTURE_FORMATS)
	i(GL_CLAMP_TO_BORDER)
	i(GL_COMBINE)
	i(GL_COMBINE_RGB)
	i(GL_COMBINE_ALPHA)
	i(GL_SOURCE0_RGB)
	i(GL_SOURCE1_RGB)
	i(GL_SOURCE2_RGB)
	i(GL_SOURCE0_ALPHA)
	i(GL_SOURCE1_ALPHA)
	i(GL_SOURCE2_ALPHA)
	i(GL_OPERAND0_RGB)
	i(GL_OPERAND1_RGB)
	i(GL_OPERAND2_RGB)
	i(GL_OPERAND0_ALPHA)
	i(GL_OPERAND1_ALPHA)
	i(GL_OPERAND2_ALPHA)
	i(GL_RGB_SCALE)
	i(GL_ADD_SIGNED)
	i(GL_INTERPOLATE)
	i(GL_SUBTRACT)
	i(GL_CONSTANT)
	i(GL_PRIMARY_COLOR)
	i(GL_PREVIOUS)
	i(GL_DOT3_RGB)
	i(GL_DOT3_RGBA)
	i(GL_BLEND_DST_RGB)
	i(GL_BLEND_SRC_RGB)
	i(GL_BLEND_DST_ALPHA)
	i(GL_BLEND_SRC_ALPHA)
	i(GL_POINT_SIZE_MIN)
	i(GL_POINT_SIZE_MAX)
	i(GL_POINT_FADE_THRESHOLD_SIZE)
	i(GL_POINT_DISTANCE_ATTENUATION)
	i(GL_GENERATE_MIPMAP)
	i(GL_GENERATE_MIPMAP_HINT)
	i(GL_DEPTH_COMPONENT16)
	i(GL_DEPTH_COMPONENT24)
	i(GL_DEPTH_COMPONENT32)
	i(GL_MIRRORED_REPEAT)
	i(GL_FOG_COORDINATE_SOURCE)
	i(GL_FOG_COORDINATE)
	i(GL_FRAGMENT_DEPTH)
	i(GL_CURRENT_FOG_COORDINATE)
	i(GL_FOG_COORDINATE_ARRAY_TYPE)
	i(GL_FOG_COORDINATE_ARRAY_STRIDE)
	i(GL_FOG_COORDINATE_ARRAY_POINTER)
	i(GL_FOG_COORDINATE_ARRAY)
	i(GL_COLOR_SUM)
	i(GL_CURRENT_SECONDARY_COLOR)
	i(GL_SECONDARY_COLOR_ARRAY_SIZE)
	i(GL_SECONDARY_COLOR_ARRAY_TYPE)
	i(GL_SECONDARY_COLOR_ARRAY_STRIDE)
	i(GL_SECONDARY_COLOR_ARRAY_POINTER)
	i(GL_SECONDARY_COLOR_ARRAY)
	i(GL_MAX_TEXTURE_LOD_BIAS)
	i(GL_TEXTURE_FILTER_CONTROL)
	i(GL_TEXTURE_LOD_BIAS)
	i(GL_INCR_WRAP)
	i(GL_DECR_WRAP)
	i(GL_TEXTURE_DEPTH_SIZE)
	i(GL_DEPTH_TEXTURE_MODE)
	i(GL_TEXTURE_COMPARE_MODE)
	i(GL_TEXTURE_COMPARE_FUNC)
	i(GL_COMPARE_R_TO_TEXTURE)
	i(GL_BUFFER_SIZE)
	i(GL_BUFFER_USAGE)
	i(GL_QUERY_COUNTER_BITS)
	i(GL_CURRENT_QUERY)
	i(GL_QUERY_RESULT)
	i(GL_QUERY_RESULT_AVAILABLE)
	i(GL_ARRAY_BUFFER)
	i(GL_ELEMENT_ARRAY_BUFFER)
	i(GL_ARRAY_BUFFER_BINDING)
	i(GL_ELEMENT_ARRAY_BUFFER_BINDING)
	i(GL_VERTEX_ARRAY_BUFFER_BINDING)
	i(GL_NORMAL_ARRAY_BUFFER_BINDING)
	i(GL_COLOR_ARRAY_BUFFER_BINDING)
	i(GL_INDEX_ARRAY_BUFFER_BINDING)
	i(GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING)
	i(GL_EDGE_FLAG_ARRAY_BUFFER_BINDING)
	i(GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING)
	i(GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING)
	i(GL_WEIGHT_ARRAY_BUFFER_BINDING)
	i(GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING)
	i(GL_READ_ONLY)
	i(GL_WRITE_ONLY)
	i(GL_READ_WRITE)
	i(GL_BUFFER_ACCESS)
	i(GL_BUFFER_MAPPED)
	i(GL_BUFFER_MAP_POINTER)
	i(GL_STREAM_DRAW)
	i(GL_STREAM_READ)
	i(GL_STREAM_COPY)
	i(GL_STATIC_DRAW)
	i(GL_STATIC_READ)
	i(GL_STATIC_COPY)
	i(GL_DYNAMIC_DRAW)
	i(GL_DYNAMIC_READ)
	i(GL_DYNAMIC_COPY)
	i(GL_SAMPLES_PASSED)
	i(GL_FOG_COORD_SRC)
	i(GL_FOG_COORD)
	i(GL_CURRENT_FOG_COORD)
	i(GL_FOG_COORD_ARRAY_TYPE)
	i(GL_FOG_COORD_ARRAY_STRIDE)
	i(GL_FOG_COORD_ARRAY_POINTER)
	i(GL_FOG_COORD_ARRAY)
	i(GL_FOG_COORD_ARRAY_BUFFER_BINDING)
	i(GL_SRC0_RGB)
	i(GL_SRC1_RGB)
	i(GL_SRC2_RGB)
	i(GL_SRC0_ALPHA)
	i(GL_SRC1_ALPHA)
	i(GL_SRC2_ALPHA)
	i(GL_BLEND_EQUATION_RGB)
	i(GL_VERTEX_ATTRIB_ARRAY_ENABLED)
	i(GL_VERTEX_ATTRIB_ARRAY_SIZE)
	i(GL_VERTEX_ATTRIB_ARRAY_STRIDE)
	i(GL_VERTEX_ATTRIB_ARRAY_TYPE)
	i(GL_CURRENT_VERTEX_ATTRIB)
	i(GL_VERTEX_PROGRAM_POINT_SIZE)
	i(GL_VERTEX_PROGRAM_TWO_SIDE)
	i(GL_VERTEX_ATTRIB_ARRAY_POINTER)
	i(GL_STENCIL_BACK_FUNC)
	i(GL_STENCIL_BACK_FAIL)
	i(GL_STENCIL_BACK_PASS_DEPTH_FAIL)
	i(GL_STENCIL_BACK_PASS_DEPTH_PASS)
	i(GL_MAX_DRAW_BUFFERS)
	i(GL_DRAW_BUFFER0)
	i(GL_DRAW_BUFFER1)
	i(GL_DRAW_BUFFER2)
	i(GL_DRAW_BUFFER3)
	i(GL_DRAW_BUFFER4)
	i(GL_DRAW_BUFFER5)
	i(GL_DRAW_BUFFER6)
	i(GL_DRAW_BUFFER7)
	i(GL_DRAW_BUFFER8)
	i(GL_DRAW_BUFFER9)
	i(GL_DRAW_BUFFER10)
	i(GL_DRAW_BUFFER11)
	i(GL_DRAW_BUFFER12)
	i(GL_DRAW_BUFFER13)
	i(GL_DRAW_BUFFER14)
	i(GL_DRAW_BUFFER15)
	i(GL_BLEND_EQUATION_ALPHA)
	i(GL_POINT_SPRITE)
	i(GL_COORD_REPLACE)
	i(GL_MAX_VERTEX_ATTRIBS)
	i(GL_VERTEX_ATTRIB_ARRAY_NORMALIZED)
	i(GL_MAX_TEXTURE_COORDS)
	i(GL_MAX_TEXTURE_IMAGE_UNITS)
	i(GL_FRAGMENT_SHADER)
	i(GL_VERTEX_SHADER)
	i(GL_MAX_FRAGMENT_UNIFORM_COMPONENTS)
	i(GL_MAX_VERTEX_UNIFORM_COMPONENTS)
	i(GL_MAX_VARYING_FLOATS)
	i(GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS)
	i(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS)
	i(GL_SHADER_TYPE)
	i(GL_FLOAT_VEC2)
	i(GL_FLOAT_VEC3)
	i(GL_FLOAT_VEC4)
	i(GL_INT_VEC2)
	i(GL_INT_VEC3)
	i(GL_INT_VEC4)
	i(GL_BOOL)
	i(GL_BOOL_VEC2)
	i(GL_BOOL_VEC3)
	i(GL_BOOL_VEC4)
	i(GL_FLOAT_MAT2)
	i(GL_FLOAT_MAT3)
	i(GL_FLOAT_MAT4)
	i(GL_SAMPLER_1D)
	i(GL_SAMPLER_2D)
	i(GL_SAMPLER_3D)
	i(GL_SAMPLER_CUBE)
	i(GL_SAMPLER_1D_SHADOW)
	i(GL_SAMPLER_2D_SHADOW)
	i(GL_DELETE_STATUS)
	i(GL_COMPILE_STATUS)
	i(GL_LINK_STATUS)
	i(GL_VALIDATE_STATUS)
	i(GL_INFO_LOG_LENGTH)
	i(GL_ATTACHED_SHADERS)
	i(GL_ACTIVE_UNIFORMS)
	i(GL_ACTIVE_UNIFORM_MAX_LENGTH)
	i(GL_SHADER_SOURCE_LENGTH)
	i(GL_ACTIVE_ATTRIBUTES)
	i(GL_ACTIVE_ATTRIBUTE_MAX_LENGTH)
	i(GL_FRAGMENT_SHADER_DERIVATIVE_HINT)
	i(GL_SHADING_LANGUAGE_VERSION)
	i(GL_CURRENT_PROGRAM)
	i(GL_POINT_SPRITE_COORD_ORIGIN)
	i(GL_LOWER_LEFT)
	i(GL_UPPER_LEFT)
	i(GL_STENCIL_BACK_REF)
	i(GL_STENCIL_BACK_VALUE_MASK)
	i(GL_STENCIL_BACK_WRITEMASK)
	i(GL_TEXTURE0_ARB)
	i(GL_TEXTURE1_ARB)
	i(GL_TEXTURE2_ARB)
	i(GL_TEXTURE3_ARB)
	i(GL_TEXTURE4_ARB)
	i(GL_TEXTURE5_ARB)
	i(GL_TEXTURE6_ARB)
	i(GL_TEXTURE7_ARB)
	i(GL_TEXTURE8_ARB)
	i(GL_TEXTURE9_ARB)
	i(GL_TEXTURE10_ARB)
	i(GL_TEXTURE11_ARB)
	i(GL_TEXTURE12_ARB)
	i(GL_TEXTURE13_ARB)
	i(GL_TEXTURE14_ARB)
	i(GL_TEXTURE15_ARB)
	i(GL_TEXTURE16_ARB)
	i(GL_TEXTURE17_ARB)
	i(GL_TEXTURE18_ARB)
	i(GL_TEXTURE19_ARB)
	i(GL_TEXTURE20_ARB)
	i(GL_TEXTURE21_ARB)
	i(GL_TEXTURE22_ARB)
	i(GL_TEXTURE23_ARB)
	i(GL_TEXTURE24_ARB)
	i(GL_TEXTURE25_ARB)
	i(GL_TEXTURE26_ARB)
	i(GL_TEXTURE27_ARB)
	i(GL_TEXTURE28_ARB)
	i(GL_TEXTURE29_ARB)
	i(GL_TEXTURE30_ARB)
	i(GL_TEXTURE31_ARB)
	i(GL_ACTIVE_TEXTURE_ARB)
	i(GL_CLIENT_ACTIVE_TEXTURE_ARB)
	i(GL_MAX_TEXTURE_UNITS_ARB)
	i(GL_TRANSPOSE_MODELVIEW_MATRIX_ARB)
	i(GL_TRANSPOSE_PROJECTION_MATRIX_ARB)
	i(GL_TRANSPOSE_TEXTURE_MATRIX_ARB)
	i(GL_TRANSPOSE_COLOR_MATRIX_ARB)
	i(GL_MULTISAMPLE_ARB)
	i(GL_SAMPLE_ALPHA_TO_COVERAGE_ARB)
	i(GL_SAMPLE_ALPHA_TO_ONE_ARB)
	i(GL_SAMPLE_COVERAGE_ARB)
	i(GL_SAMPLE_BUFFERS_ARB)
	i(GL_SAMPLES_ARB)
	i(GL_SAMPLE_COVERAGE_VALUE_ARB)
	i(GL_SAMPLE_COVERAGE_INVERT_ARB)
	i(GL_MULTISAMPLE_BIT_ARB)
	i(GL_NORMAL_MAP_ARB)
	i(GL_REFLECTION_MAP_ARB)
	i(GL_TEXTURE_CUBE_MAP_ARB)
	i(GL_TEXTURE_BINDING_CUBE_MAP_ARB)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_X_ARB)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X_ARB)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y_ARB)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_ARB)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z_ARB)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_ARB)
	i(GL_PROXY_TEXTURE_CUBE_MAP_ARB)
	i(GL_MAX_CUBE_MAP_TEXTURE_SIZE_ARB)
	i(GL_COMPRESSED_ALPHA_ARB)
	i(GL_COMPRESSED_LUMINANCE_ARB)
	i(GL_COMPRESSED_LUMINANCE_ALPHA_ARB)
	i(GL_COMPRESSED_INTENSITY_ARB)
	i(GL_COMPRESSED_RGB_ARB)
	i(GL_COMPRESSED_RGBA_ARB)
	i(GL_TEXTURE_COMPRESSION_HINT_ARB)
	i(GL_TEXTURE_COMPRESSED_IMAGE_SIZE_ARB)
	i(GL_TEXTURE_COMPRESSED_ARB)
	i(GL_NUM_COMPRESSED_TEXTURE_FORMATS_ARB)
	i(GL_COMPRESSED_TEXTURE_FORMATS_ARB)
	i(GL_CLAMP_TO_BORDER_ARB)
	i(GL_POINT_SIZE_MIN_ARB)
	i(GL_POINT_SIZE_MAX_ARB)
	i(GL_POINT_FADE_THRESHOLD_SIZE_ARB)
	i(GL_POINT_DISTANCE_ATTENUATION_ARB)
	i(GL_MAX_VERTEX_UNITS_ARB)
	i(GL_ACTIVE_VERTEX_UNITS_ARB)
	i(GL_WEIGHT_SUM_UNITY_ARB)
	i(GL_VERTEX_BLEND_ARB)
	i(GL_CURRENT_WEIGHT_ARB)
	i(GL_WEIGHT_ARRAY_TYPE_ARB)
	i(GL_WEIGHT_ARRAY_STRIDE_ARB)
	i(GL_WEIGHT_ARRAY_SIZE_ARB)
	i(GL_WEIGHT_ARRAY_POINTER_ARB)
	i(GL_WEIGHT_ARRAY_ARB)
	i(GL_MODELVIEW0_ARB)
	i(GL_MODELVIEW1_ARB)
	i(GL_MODELVIEW2_ARB)
	i(GL_MODELVIEW3_ARB)
	i(GL_MODELVIEW4_ARB)
	i(GL_MODELVIEW5_ARB)
	i(GL_MODELVIEW6_ARB)
	i(GL_MODELVIEW7_ARB)
	i(GL_MODELVIEW8_ARB)
	i(GL_MODELVIEW9_ARB)
	i(GL_MODELVIEW10_ARB)
	i(GL_MODELVIEW11_ARB)
	i(GL_MODELVIEW12_ARB)
	i(GL_MODELVIEW13_ARB)
	i(GL_MODELVIEW14_ARB)
	i(GL_MODELVIEW15_ARB)
	i(GL_MODELVIEW16_ARB)
	i(GL_MODELVIEW17_ARB)
	i(GL_MODELVIEW18_ARB)
	i(GL_MODELVIEW19_ARB)
	i(GL_MODELVIEW20_ARB)
	i(GL_MODELVIEW21_ARB)
	i(GL_MODELVIEW22_ARB)
	i(GL_MODELVIEW23_ARB)
	i(GL_MODELVIEW24_ARB)
	i(GL_MODELVIEW25_ARB)
	i(GL_MODELVIEW26_ARB)
	i(GL_MODELVIEW27_ARB)
	i(GL_MODELVIEW28_ARB)
	i(GL_MODELVIEW29_ARB)
	i(GL_MODELVIEW30_ARB)
	i(GL_MODELVIEW31_ARB)
	i(GL_MATRIX_PALETTE_ARB)
	i(GL_MAX_MATRIX_PALETTE_STACK_DEPTH_ARB)
	i(GL_MAX_PALETTE_MATRICES_ARB)
	i(GL_CURRENT_PALETTE_MATRIX_ARB)
	i(GL_MATRIX_INDEX_ARRAY_ARB)
	i(GL_CURRENT_MATRIX_INDEX_ARB)
	i(GL_MATRIX_INDEX_ARRAY_SIZE_ARB)
	i(GL_MATRIX_INDEX_ARRAY_TYPE_ARB)
	i(GL_MATRIX_INDEX_ARRAY_STRIDE_ARB)
	i(GL_MATRIX_INDEX_ARRAY_POINTER_ARB)
	i(GL_COMBINE_ARB)
	i(GL_COMBINE_RGB_ARB)
	i(GL_COMBINE_ALPHA_ARB)
	i(GL_SOURCE0_RGB_ARB)
	i(GL_SOURCE1_RGB_ARB)
	i(GL_SOURCE2_RGB_ARB)
	i(GL_SOURCE0_ALPHA_ARB)
	i(GL_SOURCE1_ALPHA_ARB)
	i(GL_SOURCE2_ALPHA_ARB)
	i(GL_OPERAND0_RGB_ARB)
	i(GL_OPERAND1_RGB_ARB)
	i(GL_OPERAND2_RGB_ARB)
	i(GL_OPERAND0_ALPHA_ARB)
	i(GL_OPERAND1_ALPHA_ARB)
	i(GL_OPERAND2_ALPHA_ARB)
	i(GL_RGB_SCALE_ARB)
	i(GL_ADD_SIGNED_ARB)
	i(GL_INTERPOLATE_ARB)
	i(GL_SUBTRACT_ARB)
	i(GL_CONSTANT_ARB)
	i(GL_PRIMARY_COLOR_ARB)
	i(GL_PREVIOUS_ARB)
	i(GL_DOT3_RGB_ARB)
	i(GL_DOT3_RGBA_ARB)
	i(GL_MIRRORED_REPEAT_ARB)
	i(GL_DEPTH_COMPONENT16_ARB)
	i(GL_DEPTH_COMPONENT24_ARB)
	i(GL_DEPTH_COMPONENT32_ARB)
	i(GL_TEXTURE_DEPTH_SIZE_ARB)
	i(GL_DEPTH_TEXTURE_MODE_ARB)
	i(GL_TEXTURE_COMPARE_MODE_ARB)
	i(GL_TEXTURE_COMPARE_FUNC_ARB)
	i(GL_COMPARE_R_TO_TEXTURE_ARB)
	i(GL_TEXTURE_COMPARE_FAIL_VALUE_ARB)
	i(GL_COLOR_SUM_ARB)
	i(GL_VERTEX_PROGRAM_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB)
	i(GL_CURRENT_VERTEX_ATTRIB_ARB)
	i(GL_PROGRAM_LENGTH_ARB)
	i(GL_PROGRAM_STRING_ARB)
	i(GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB)
	i(GL_MAX_PROGRAM_MATRICES_ARB)
	i(GL_CURRENT_MATRIX_STACK_DEPTH_ARB)
	i(GL_CURRENT_MATRIX_ARB)
	i(GL_VERTEX_PROGRAM_POINT_SIZE_ARB)
	i(GL_VERTEX_PROGRAM_TWO_SIDE_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB)
	i(GL_PROGRAM_ERROR_POSITION_ARB)
	i(GL_PROGRAM_BINDING_ARB)
	i(GL_MAX_VERTEX_ATTRIBS_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB)
	i(GL_PROGRAM_ERROR_STRING_ARB)
	i(GL_PROGRAM_FORMAT_ASCII_ARB)
	i(GL_PROGRAM_FORMAT_ARB)
	i(GL_PROGRAM_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_TEMPORARIES_ARB)
	i(GL_MAX_PROGRAM_TEMPORARIES_ARB)
	i(GL_PROGRAM_NATIVE_TEMPORARIES_ARB)
	i(GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB)
	i(GL_PROGRAM_PARAMETERS_ARB)
	i(GL_MAX_PROGRAM_PARAMETERS_ARB)
	i(GL_PROGRAM_NATIVE_PARAMETERS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB)
	i(GL_PROGRAM_ATTRIBS_ARB)
	i(GL_MAX_PROGRAM_ATTRIBS_ARB)
	i(GL_PROGRAM_NATIVE_ATTRIBS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB)
	i(GL_PROGRAM_ADDRESS_REGISTERS_ARB)
	i(GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB)
	i(GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB)
	i(GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB)
	i(GL_MAX_PROGRAM_ENV_PARAMETERS_ARB)
	i(GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB)
	i(GL_TRANSPOSE_CURRENT_MATRIX_ARB)
	i(GL_MATRIX0_ARB)
	i(GL_MATRIX1_ARB)
	i(GL_MATRIX2_ARB)
	i(GL_MATRIX3_ARB)
	i(GL_MATRIX4_ARB)
	i(GL_MATRIX5_ARB)
	i(GL_MATRIX6_ARB)
	i(GL_MATRIX7_ARB)
	i(GL_MATRIX8_ARB)
	i(GL_MATRIX9_ARB)
	i(GL_MATRIX10_ARB)
	i(GL_MATRIX11_ARB)
	i(GL_MATRIX12_ARB)
	i(GL_MATRIX13_ARB)
	i(GL_MATRIX14_ARB)
	i(GL_MATRIX15_ARB)
	i(GL_MATRIX16_ARB)
	i(GL_MATRIX17_ARB)
	i(GL_MATRIX18_ARB)
	i(GL_MATRIX19_ARB)
	i(GL_MATRIX20_ARB)
	i(GL_MATRIX21_ARB)
	i(GL_MATRIX22_ARB)
	i(GL_MATRIX23_ARB)
	i(GL_MATRIX24_ARB)
	i(GL_MATRIX25_ARB)
	i(GL_MATRIX26_ARB)
	i(GL_MATRIX27_ARB)
	i(GL_MATRIX28_ARB)
	i(GL_MATRIX29_ARB)
	i(GL_MATRIX30_ARB)
	i(GL_MATRIX31_ARB)
	i(GL_FRAGMENT_PROGRAM_ARB)
	i(GL_PROGRAM_ALU_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_TEX_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_TEX_INDIRECTIONS_ARB)
	i(GL_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB)
	i(GL_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB)
	i(GL_MAX_PROGRAM_ALU_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_TEX_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_TEX_INDIRECTIONS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_ALU_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_TEX_INSTRUCTIONS_ARB)
	i(GL_MAX_PROGRAM_NATIVE_TEX_INDIRECTIONS_ARB)
	i(GL_MAX_TEXTURE_COORDS_ARB)
	i(GL_MAX_TEXTURE_IMAGE_UNITS_ARB)
	i(GL_BUFFER_SIZE_ARB)
	i(GL_BUFFER_USAGE_ARB)
	i(GL_ARRAY_BUFFER_ARB)
	i(GL_ELEMENT_ARRAY_BUFFER_ARB)
	i(GL_ARRAY_BUFFER_BINDING_ARB)
	i(GL_ELEMENT_ARRAY_BUFFER_BINDING_ARB)
	i(GL_VERTEX_ARRAY_BUFFER_BINDING_ARB)
	i(GL_NORMAL_ARRAY_BUFFER_BINDING_ARB)
	i(GL_COLOR_ARRAY_BUFFER_BINDING_ARB)
	i(GL_INDEX_ARRAY_BUFFER_BINDING_ARB)
	i(GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING_ARB)
	i(GL_EDGE_FLAG_ARRAY_BUFFER_BINDING_ARB)
	i(GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING_ARB)
	i(GL_FOG_COORDINATE_ARRAY_BUFFER_BINDING_ARB)
	i(GL_WEIGHT_ARRAY_BUFFER_BINDING_ARB)
	i(GL_VERTEX_ATTRIB_ARRAY_BUFFER_BINDING_ARB)
	i(GL_READ_ONLY_ARB)
	i(GL_WRITE_ONLY_ARB)
	i(GL_READ_WRITE_ARB)
	i(GL_BUFFER_ACCESS_ARB)
	i(GL_BUFFER_MAPPED_ARB)
	i(GL_BUFFER_MAP_POINTER_ARB)
	i(GL_STREAM_DRAW_ARB)
	i(GL_STREAM_READ_ARB)
	i(GL_STREAM_COPY_ARB)
	i(GL_STATIC_DRAW_ARB)
	i(GL_STATIC_READ_ARB)
	i(GL_STATIC_COPY_ARB)
	i(GL_DYNAMIC_DRAW_ARB)
	i(GL_DYNAMIC_READ_ARB)
	i(GL_DYNAMIC_COPY_ARB)
	i(GL_QUERY_COUNTER_BITS_ARB)
	i(GL_CURRENT_QUERY_ARB)
	i(GL_QUERY_RESULT_ARB)
	i(GL_QUERY_RESULT_AVAILABLE_ARB)
	i(GL_SAMPLES_PASSED_ARB)
	i(GL_PROGRAM_OBJECT_ARB)
	i(GL_SHADER_OBJECT_ARB)
	i(GL_OBJECT_TYPE_ARB)
	i(GL_OBJECT_SUBTYPE_ARB)
	i(GL_FLOAT_VEC2_ARB)
	i(GL_FLOAT_VEC3_ARB)
	i(GL_FLOAT_VEC4_ARB)
	i(GL_INT_VEC2_ARB)
	i(GL_INT_VEC3_ARB)
	i(GL_INT_VEC4_ARB)
	i(GL_BOOL_ARB)
	i(GL_BOOL_VEC2_ARB)
	i(GL_BOOL_VEC3_ARB)
	i(GL_BOOL_VEC4_ARB)
	i(GL_FLOAT_MAT2_ARB)
	i(GL_FLOAT_MAT3_ARB)
	i(GL_FLOAT_MAT4_ARB)
	i(GL_SAMPLER_1D_ARB)
	i(GL_SAMPLER_2D_ARB)
	i(GL_SAMPLER_3D_ARB)
	i(GL_SAMPLER_CUBE_ARB)
	i(GL_SAMPLER_1D_SHADOW_ARB)
	i(GL_SAMPLER_2D_SHADOW_ARB)
	i(GL_SAMPLER_2D_RECT_ARB)
	i(GL_SAMPLER_2D_RECT_SHADOW_ARB)
	i(GL_OBJECT_DELETE_STATUS_ARB)
	i(GL_OBJECT_COMPILE_STATUS_ARB)
	i(GL_OBJECT_LINK_STATUS_ARB)
	i(GL_OBJECT_VALIDATE_STATUS_ARB)
	i(GL_OBJECT_INFO_LOG_LENGTH_ARB)
	i(GL_OBJECT_ATTACHED_OBJECTS_ARB)
	i(GL_OBJECT_ACTIVE_UNIFORMS_ARB)
	i(GL_OBJECT_ACTIVE_UNIFORM_MAX_LENGTH_ARB)
	i(GL_OBJECT_SHADER_SOURCE_LENGTH_ARB)
	i(GL_VERTEX_SHADER_ARB)
	i(GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB)
	i(GL_MAX_VARYING_FLOATS_ARB)
	i(GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB)
	i(GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB)
	i(GL_OBJECT_ACTIVE_ATTRIBUTES_ARB)
	i(GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB)
	i(GL_FRAGMENT_SHADER_ARB)
	i(GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB)
	i(GL_FRAGMENT_SHADER_DERIVATIVE_HINT_ARB)
	i(GL_SHADING_LANGUAGE_VERSION_ARB)
	i(GL_POINT_SPRITE_ARB)
	i(GL_COORD_REPLACE_ARB)
	i(GL_MAX_DRAW_BUFFERS_ARB)
	i(GL_DRAW_BUFFER0_ARB)
	i(GL_DRAW_BUFFER1_ARB)
	i(GL_DRAW_BUFFER2_ARB)
	i(GL_DRAW_BUFFER3_ARB)
	i(GL_DRAW_BUFFER4_ARB)
	i(GL_DRAW_BUFFER5_ARB)
	i(GL_DRAW_BUFFER6_ARB)
	i(GL_DRAW_BUFFER7_ARB)
	i(GL_DRAW_BUFFER8_ARB)
	i(GL_DRAW_BUFFER9_ARB)
	i(GL_DRAW_BUFFER10_ARB)
	i(GL_DRAW_BUFFER11_ARB)
	i(GL_DRAW_BUFFER12_ARB)
	i(GL_DRAW_BUFFER13_ARB)
	i(GL_DRAW_BUFFER14_ARB)
	i(GL_DRAW_BUFFER15_ARB)
	i(GL_TEXTURE_RECTANGLE_ARB)
	i(GL_TEXTURE_BINDING_RECTANGLE_ARB)
	i(GL_PROXY_TEXTURE_RECTANGLE_ARB)
	i(GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB)
	i(GL_RGBA_FLOAT_MODE_ARB)
	i(GL_CLAMP_VERTEX_COLOR_ARB)
	i(GL_CLAMP_FRAGMENT_COLOR_ARB)
	i(GL_CLAMP_READ_COLOR_ARB)
	i(GL_FIXED_ONLY_ARB)
	i(GL_HALF_FLOAT_ARB)
	i(GL_TEXTURE_RED_TYPE_ARB)
	i(GL_TEXTURE_GREEN_TYPE_ARB)
	i(GL_TEXTURE_BLUE_TYPE_ARB)
	i(GL_TEXTURE_ALPHA_TYPE_ARB)
	i(GL_TEXTURE_LUMINANCE_TYPE_ARB)
	i(GL_TEXTURE_INTENSITY_TYPE_ARB)
	i(GL_TEXTURE_DEPTH_TYPE_ARB)
	i(GL_UNSIGNED_NORMALIZED_ARB)
	i(GL_RGBA32F_ARB)
	i(GL_RGB32F_ARB)
	i(GL_ALPHA32F_ARB)
	i(GL_INTENSITY32F_ARB)
	i(GL_LUMINANCE32F_ARB)
	i(GL_LUMINANCE_ALPHA32F_ARB)
	i(GL_RGBA16F_ARB)
	i(GL_RGB16F_ARB)
	i(GL_ALPHA16F_ARB)
	i(GL_INTENSITY16F_ARB)
	i(GL_LUMINANCE16F_ARB)
	i(GL_LUMINANCE_ALPHA16F_ARB)
	i(GL_PIXEL_PACK_BUFFER_ARB)
	i(GL_PIXEL_UNPACK_BUFFER_ARB)
	i(GL_PIXEL_PACK_BUFFER_BINDING_ARB)
	i(GL_PIXEL_UNPACK_BUFFER_BINDING_ARB)
	i(GL_RGB2_EXT)
	i(GL_PROXY_TEXTURE_1D_EXT)
	i(GL_PROXY_TEXTURE_2D_EXT)
	i(GL_FILTER4_SGIS)
	i(GL_TEXTURE_FILTER4_SIZE_SGIS)
	i(GL_HISTOGRAM_EXT)
	i(GL_PROXY_HISTOGRAM_EXT)
	i(GL_HISTOGRAM_WIDTH_EXT)
	i(GL_HISTOGRAM_FORMAT_EXT)
	i(GL_HISTOGRAM_RED_SIZE_EXT)
	i(GL_HISTOGRAM_GREEN_SIZE_EXT)
	i(GL_HISTOGRAM_BLUE_SIZE_EXT)
	i(GL_HISTOGRAM_ALPHA_SIZE_EXT)
	i(GL_HISTOGRAM_LUMINANCE_SIZE_EXT)
	i(GL_HISTOGRAM_SINK_EXT)
	i(GL_MINMAX_EXT)
	i(GL_MINMAX_FORMAT_EXT)
	i(GL_MINMAX_SINK_EXT)
	i(GL_CONVOLUTION_1D_EXT)
	i(GL_CONVOLUTION_2D_EXT)
	i(GL_SEPARABLE_2D_EXT)
	i(GL_CONVOLUTION_BORDER_MODE_EXT)
	i(GL_CONVOLUTION_FILTER_SCALE_EXT)
	i(GL_CONVOLUTION_FILTER_BIAS_EXT)
	i(GL_REDUCE_EXT)
	i(GL_CONVOLUTION_FORMAT_EXT)
	i(GL_CONVOLUTION_WIDTH_EXT)
	i(GL_CONVOLUTION_HEIGHT_EXT)
	i(GL_MAX_CONVOLUTION_WIDTH_EXT)
	i(GL_MAX_CONVOLUTION_HEIGHT_EXT)
	i(GL_POST_CONVOLUTION_RED_SCALE_EXT)
	i(GL_POST_CONVOLUTION_GREEN_SCALE_EXT)
	i(GL_POST_CONVOLUTION_BLUE_SCALE_EXT)
	i(GL_POST_CONVOLUTION_ALPHA_SCALE_EXT)
	i(GL_POST_CONVOLUTION_RED_BIAS_EXT)
	i(GL_POST_CONVOLUTION_GREEN_BIAS_EXT)
	i(GL_POST_CONVOLUTION_BLUE_BIAS_EXT)
	i(GL_POST_CONVOLUTION_ALPHA_BIAS_EXT)
	i(GL_COLOR_MATRIX_SGI)
	i(GL_COLOR_MATRIX_STACK_DEPTH_SGI)
	i(GL_MAX_COLOR_MATRIX_STACK_DEPTH_SGI)
	i(GL_POST_COLOR_MATRIX_RED_SCALE_SGI)
	i(GL_POST_COLOR_MATRIX_GREEN_SCALE_SGI)
	i(GL_POST_COLOR_MATRIX_BLUE_SCALE_SGI)
	i(GL_POST_COLOR_MATRIX_ALPHA_SCALE_SGI)
	i(GL_POST_COLOR_MATRIX_RED_BIAS_SGI)
	i(GL_POST_COLOR_MATRIX_GREEN_BIAS_SGI)
	i(GL_POST_COLOR_MATRIX_BLUE_BIAS_SGI)
	i(GL_POST_COLOR_MATRIX_ALPHA_BIAS_SGI)
	i(GL_COLOR_TABLE_SGI)
	i(GL_POST_CONVOLUTION_COLOR_TABLE_SGI)
	i(GL_POST_COLOR_MATRIX_COLOR_TABLE_SGI)
	i(GL_PROXY_COLOR_TABLE_SGI)
	i(GL_PROXY_POST_CONVOLUTION_COLOR_TABLE_SGI)
	i(GL_PROXY_POST_COLOR_MATRIX_COLOR_TABLE_SGI)
	i(GL_COLOR_TABLE_SCALE_SGI)
	i(GL_COLOR_TABLE_BIAS_SGI)
	i(GL_COLOR_TABLE_FORMAT_SGI)
	i(GL_COLOR_TABLE_WIDTH_SGI)
	i(GL_COLOR_TABLE_RED_SIZE_SGI)
	i(GL_COLOR_TABLE_GREEN_SIZE_SGI)
	i(GL_COLOR_TABLE_BLUE_SIZE_SGI)
	i(GL_COLOR_TABLE_ALPHA_SIZE_SGI)
	i(GL_COLOR_TABLE_LUMINANCE_SIZE_SGI)
	i(GL_COLOR_TABLE_INTENSITY_SIZE_SGI)
	i(GL_PIXEL_TEXTURE_SGIS)
	i(GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS)
	i(GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS)
	i(GL_PIXEL_GROUP_COLOR_SGIS)
	i(GL_PIXEL_TEX_GEN_SGIX)
	i(GL_PIXEL_TEX_GEN_MODE_SGIX)
	i(GL_PACK_SKIP_VOLUMES_SGIS)
	i(GL_PACK_IMAGE_DEPTH_SGIS)
	i(GL_UNPACK_SKIP_VOLUMES_SGIS)
	i(GL_UNPACK_IMAGE_DEPTH_SGIS)
	i(GL_TEXTURE_4D_SGIS)
	i(GL_PROXY_TEXTURE_4D_SGIS)
	i(GL_TEXTURE_4DSIZE_SGIS)
	i(GL_TEXTURE_WRAP_Q_SGIS)
	i(GL_MAX_4D_TEXTURE_SIZE_SGIS)
	i(GL_TEXTURE_4D_BINDING_SGIS)
	i(GL_TEXTURE_COLOR_TABLE_SGI)
	i(GL_PROXY_TEXTURE_COLOR_TABLE_SGI)
	i(GL_DETAIL_TEXTURE_2D_SGIS)
	i(GL_DETAIL_TEXTURE_2D_BINDING_SGIS)
	i(GL_LINEAR_DETAIL_SGIS)
	i(GL_LINEAR_DETAIL_ALPHA_SGIS)
	i(GL_LINEAR_DETAIL_COLOR_SGIS)
	i(GL_DETAIL_TEXTURE_LEVEL_SGIS)
	i(GL_DETAIL_TEXTURE_MODE_SGIS)
	i(GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS)
	i(GL_LINEAR_SHARPEN_SGIS)
	i(GL_LINEAR_SHARPEN_ALPHA_SGIS)
	i(GL_LINEAR_SHARPEN_COLOR_SGIS)
	i(GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS)
	i(GL_UNSIGNED_BYTE_3_3_2_EXT)
	i(GL_UNSIGNED_SHORT_4_4_4_4_EXT)
	i(GL_UNSIGNED_SHORT_5_5_5_1_EXT)
	i(GL_UNSIGNED_INT_8_8_8_8_EXT)
	i(GL_UNSIGNED_INT_10_10_10_2_EXT)
	i(GL_TEXTURE_MIN_LOD_SGIS)
	i(GL_TEXTURE_MAX_LOD_SGIS)
	i(GL_TEXTURE_BASE_LEVEL_SGIS)
	i(GL_TEXTURE_MAX_LEVEL_SGIS)
	i(GL_MULTISAMPLE_SGIS)
	i(GL_SAMPLE_ALPHA_TO_MASK_SGIS)
	i(GL_SAMPLE_ALPHA_TO_ONE_SGIS)
	i(GL_SAMPLE_MASK_SGIS)
	i(GL_1PASS_SGIS)
	i(GL_2PASS_0_SGIS)
	i(GL_2PASS_1_SGIS)
	i(GL_4PASS_0_SGIS)
	i(GL_4PASS_1_SGIS)
	i(GL_4PASS_2_SGIS)
	i(GL_4PASS_3_SGIS)
	i(GL_SAMPLE_BUFFERS_SGIS)
	i(GL_SAMPLES_SGIS)
	i(GL_SAMPLE_MASK_VALUE_SGIS)
	i(GL_SAMPLE_MASK_INVERT_SGIS)
	i(GL_SAMPLE_PATTERN_SGIS)
	i(GL_RESCALE_NORMAL_EXT)
	i(GL_GENERATE_MIPMAP_SGIS)
	i(GL_GENERATE_MIPMAP_HINT_SGIS)
	i(GL_LINEAR_CLIPMAP_LINEAR_SGIX)
	i(GL_TEXTURE_CLIPMAP_CENTER_SGIX)
	i(GL_TEXTURE_CLIPMAP_FRAME_SGIX)
	i(GL_TEXTURE_CLIPMAP_OFFSET_SGIX)
	i(GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX)
	i(GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX)
	i(GL_TEXTURE_CLIPMAP_DEPTH_SGIX)
	i(GL_MAX_CLIPMAP_DEPTH_SGIX)
	i(GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX)
	i(GL_NEAREST_CLIPMAP_NEAREST_SGIX)
	i(GL_NEAREST_CLIPMAP_LINEAR_SGIX)
	i(GL_LINEAR_CLIPMAP_NEAREST_SGIX)
	i(GL_TEXTURE_COMPARE_SGIX)
	i(GL_TEXTURE_COMPARE_OPERATOR_SGIX)
	i(GL_TEXTURE_LEQUAL_R_SGIX)
	i(GL_TEXTURE_GEQUAL_R_SGIX)
	i(GL_CLAMP_TO_EDGE_SGIS)
	i(GL_CLAMP_TO_BORDER_SGIS)
	i(GL_INTERLACE_SGIX)
	i(GL_PIXEL_TILE_BEST_ALIGNMENT_SGIX)
	i(GL_PIXEL_TILE_CACHE_INCREMENT_SGIX)
	i(GL_PIXEL_TILE_WIDTH_SGIX)
	i(GL_PIXEL_TILE_HEIGHT_SGIX)
	i(GL_PIXEL_TILE_GRID_WIDTH_SGIX)
	i(GL_PIXEL_TILE_GRID_HEIGHT_SGIX)
	i(GL_PIXEL_TILE_GRID_DEPTH_SGIX)
	i(GL_PIXEL_TILE_CACHE_SIZE_SGIX)
	i(GL_DUAL_ALPHA4_SGIS)
	i(GL_DUAL_ALPHA8_SGIS)
	i(GL_DUAL_ALPHA12_SGIS)
	i(GL_DUAL_ALPHA16_SGIS)
	i(GL_DUAL_LUMINANCE4_SGIS)
	i(GL_DUAL_LUMINANCE8_SGIS)
	i(GL_DUAL_LUMINANCE12_SGIS)
	i(GL_DUAL_LUMINANCE16_SGIS)
	i(GL_DUAL_INTENSITY4_SGIS)
	i(GL_DUAL_INTENSITY8_SGIS)
	i(GL_DUAL_INTENSITY12_SGIS)
	i(GL_DUAL_INTENSITY16_SGIS)
	i(GL_DUAL_LUMINANCE_ALPHA4_SGIS)
	i(GL_DUAL_LUMINANCE_ALPHA8_SGIS)
	i(GL_QUAD_ALPHA4_SGIS)
	i(GL_QUAD_ALPHA8_SGIS)
	i(GL_QUAD_LUMINANCE4_SGIS)
	i(GL_QUAD_LUMINANCE8_SGIS)
	i(GL_QUAD_INTENSITY4_SGIS)
	i(GL_QUAD_INTENSITY8_SGIS)
	i(GL_DUAL_TEXTURE_SELECT_SGIS)
	i(GL_QUAD_TEXTURE_SELECT_SGIS)
	i(GL_SPRITE_SGIX)
	i(GL_SPRITE_MODE_SGIX)
	i(GL_SPRITE_AXIS_SGIX)
	i(GL_SPRITE_TRANSLATION_SGIX)
	i(GL_SPRITE_AXIAL_SGIX)
	i(GL_SPRITE_OBJECT_ALIGNED_SGIX)
	i(GL_SPRITE_EYE_ALIGNED_SGIX)
	i(GL_TEXTURE_MULTI_BUFFER_HINT_SGIX)
	i(GL_POINT_SIZE_MIN_SGIS)
	i(GL_POINT_SIZE_MAX_SGIS)
	i(GL_POINT_FADE_THRESHOLD_SIZE_SGIS)
	i(GL_DISTANCE_ATTENUATION_SGIS)
	i(GL_INSTRUMENT_BUFFER_POINTER_SGIX)
	i(GL_INSTRUMENT_MEASUREMENTS_SGIX)
	i(GL_POST_TEXTURE_FILTER_BIAS_SGIX)
	i(GL_POST_TEXTURE_FILTER_SCALE_SGIX)
	i(GL_POST_TEXTURE_FILTER_BIAS_RANGE_SGIX)
	i(GL_POST_TEXTURE_FILTER_SCALE_RANGE_SGIX)
	i(GL_FRAMEZOOM_SGIX)
	i(GL_FRAMEZOOM_FACTOR_SGIX)
	i(GL_MAX_FRAMEZOOM_FACTOR_SGIX)
	i(GL_TEXTURE_DEFORMATION_BIT_SGIX)
	i(GL_GEOMETRY_DEFORMATION_BIT_SGIX)
	i(GL_GEOMETRY_DEFORMATION_SGIX)
	i(GL_TEXTURE_DEFORMATION_SGIX)
	i(GL_DEFORMATIONS_MASK_SGIX)
	i(GL_MAX_DEFORMATION_ORDER_SGIX)
	i(GL_REFERENCE_PLANE_SGIX)
	i(GL_REFERENCE_PLANE_EQUATION_SGIX)
	i(GL_DEPTH_COMPONENT16_SGIX)
	i(GL_DEPTH_COMPONENT24_SGIX)
	i(GL_DEPTH_COMPONENT32_SGIX)
	i(GL_FOG_FUNC_SGIS)
	i(GL_FOG_FUNC_POINTS_SGIS)
	i(GL_MAX_FOG_FUNC_POINTS_SGIS)
	i(GL_FOG_OFFSET_SGIX)
	i(GL_FOG_OFFSET_VALUE_SGIX)
	i(GL_IMAGE_SCALE_X_HP)
	i(GL_IMAGE_SCALE_Y_HP)
	i(GL_IMAGE_TRANSLATE_X_HP)
	i(GL_IMAGE_TRANSLATE_Y_HP)
	i(GL_IMAGE_ROTATE_ANGLE_HP)
	i(GL_IMAGE_ROTATE_ORIGIN_X_HP)
	i(GL_IMAGE_ROTATE_ORIGIN_Y_HP)
	i(GL_IMAGE_MAG_FILTER_HP)
	i(GL_IMAGE_MIN_FILTER_HP)
	i(GL_IMAGE_CUBIC_WEIGHT_HP)
	i(GL_CUBIC_HP)
	i(GL_AVERAGE_HP)
	i(GL_IMAGE_TRANSFORM_2D_HP)
	i(GL_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP)
	i(GL_PROXY_POST_IMAGE_TRANSFORM_COLOR_TABLE_HP)
	i(GL_IGNORE_BORDER_HP)
	i(GL_CONSTANT_BORDER_HP)
	i(GL_REPLICATE_BORDER_HP)
	i(GL_CONVOLUTION_BORDER_COLOR_HP)
	i(GL_TEXTURE_ENV_BIAS_SGIX)
	i(GL_VERTEX_DATA_HINT_PGI)
	i(GL_VERTEX_CONSISTENT_HINT_PGI)
	i(GL_MATERIAL_SIDE_HINT_PGI)
	i(GL_MAX_VERTEX_HINT_PGI)
	i(GL_COLOR3_BIT_PGI)
	i(GL_COLOR4_BIT_PGI)
	i(GL_EDGEFLAG_BIT_PGI)
	i(GL_INDEX_BIT_PGI)
	i(GL_MAT_AMBIENT_BIT_PGI)
	i(GL_MAT_AMBIENT_AND_DIFFUSE_BIT_PGI)
	i(GL_MAT_DIFFUSE_BIT_PGI)
	i(GL_MAT_EMISSION_BIT_PGI)
	i(GL_MAT_COLOR_INDEXES_BIT_PGI)
	i(GL_MAT_SHININESS_BIT_PGI)
	i(GL_MAT_SPECULAR_BIT_PGI)
	i(GL_NORMAL_BIT_PGI)
	i(GL_TEXCOORD1_BIT_PGI)
	i(GL_TEXCOORD2_BIT_PGI)
	i(GL_TEXCOORD3_BIT_PGI)
	i(GL_TEXCOORD4_BIT_PGI)
	i(GL_VERTEX23_BIT_PGI)
	i(GL_VERTEX4_BIT_PGI)
	i(GL_PREFER_DOUBLEBUFFER_HINT_PGI)
	i(GL_CONSERVE_MEMORY_HINT_PGI)
	i(GL_RECLAIM_MEMORY_HINT_PGI)
	i(GL_NATIVE_GRAPHICS_HANDLE_PGI)
	i(GL_NATIVE_GRAPHICS_BEGIN_HINT_PGI)
	i(GL_NATIVE_GRAPHICS_END_HINT_PGI)
	i(GL_ALWAYS_FAST_HINT_PGI)
	i(GL_ALWAYS_SOFT_HINT_PGI)
	i(GL_ALLOW_DRAW_OBJ_HINT_PGI)
	i(GL_ALLOW_DRAW_WIN_HINT_PGI)
	i(GL_ALLOW_DRAW_FRG_HINT_PGI)
	i(GL_ALLOW_DRAW_MEM_HINT_PGI)
	i(GL_STRICT_DEPTHFUNC_HINT_PGI)
	i(GL_STRICT_LIGHTING_HINT_PGI)
	i(GL_STRICT_SCISSOR_HINT_PGI)
	i(GL_FULL_STIPPLE_HINT_PGI)
	i(GL_CLIP_NEAR_HINT_PGI)
	i(GL_CLIP_FAR_HINT_PGI)
	i(GL_WIDE_LINE_HINT_PGI)
	i(GL_BACK_NORMALS_HINT_PGI)
	i(GL_CLIP_VOLUME_CLIPPING_HINT_EXT)
	i(GL_LIST_PRIORITY_SGIX)
	i(GL_IR_INSTRUMENT1_SGIX)
	i(GL_CALLIGRAPHIC_FRAGMENT_SGIX)
	i(GL_TEXTURE_LOD_BIAS_S_SGIX)
	i(GL_TEXTURE_LOD_BIAS_T_SGIX)
	i(GL_TEXTURE_LOD_BIAS_R_SGIX)
	i(GL_SHADOW_AMBIENT_SGIX)
	i(GL_INDEX_MATERIAL_EXT)
	i(GL_INDEX_MATERIAL_PARAMETER_EXT)
	i(GL_INDEX_MATERIAL_FACE_EXT)
	i(GL_INDEX_TEST_EXT)
	i(GL_INDEX_TEST_FUNC_EXT)
	i(GL_INDEX_TEST_REF_EXT)
	i(GL_IUI_V2F_EXT)
	i(GL_IUI_V3F_EXT)
	i(GL_IUI_N3F_V2F_EXT)
	i(GL_IUI_N3F_V3F_EXT)
	i(GL_T2F_IUI_V2F_EXT)
	i(GL_T2F_IUI_V3F_EXT)
	i(GL_T2F_IUI_N3F_V2F_EXT)
	i(GL_T2F_IUI_N3F_V3F_EXT)
	i(GL_ARRAY_ELEMENT_LOCK_FIRST_EXT)
	i(GL_ARRAY_ELEMENT_LOCK_COUNT_EXT)
	i(GL_CULL_VERTEX_EXT)
	i(GL_CULL_VERTEX_EYE_POSITION_EXT)
	i(GL_CULL_VERTEX_OBJECT_POSITION_EXT)
	i(GL_YCRCB_422_SGIX)
	i(GL_YCRCB_444_SGIX)
	i(GL_FRAGMENT_LIGHTING_SGIX)
	i(GL_FRAGMENT_COLOR_MATERIAL_SGIX)
	i(GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX)
	i(GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX)
	i(GL_MAX_FRAGMENT_LIGHTS_SGIX)
	i(GL_MAX_ACTIVE_LIGHTS_SGIX)
	i(GL_CURRENT_RASTER_NORMAL_SGIX)
	i(GL_LIGHT_ENV_MODE_SGIX)
	i(GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX)
	i(GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX)
	i(GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX)
	i(GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX)
	i(GL_FRAGMENT_LIGHT0_SGIX)
	i(GL_FRAGMENT_LIGHT1_SGIX)
	i(GL_FRAGMENT_LIGHT2_SGIX)
	i(GL_FRAGMENT_LIGHT3_SGIX)
	i(GL_FRAGMENT_LIGHT4_SGIX)
	i(GL_FRAGMENT_LIGHT5_SGIX)
	i(GL_FRAGMENT_LIGHT6_SGIX)
	i(GL_FRAGMENT_LIGHT7_SGIX)
	i(GL_RASTER_POSITION_UNCLIPPED_IBM)
	i(GL_TEXTURE_LIGHTING_MODE_HP)
	i(GL_TEXTURE_POST_SPECULAR_HP)
	i(GL_TEXTURE_PRE_SPECULAR_HP)
	i(GL_MAX_ELEMENTS_VERTICES_EXT)
	i(GL_MAX_ELEMENTS_INDICES_EXT)
	i(GL_PHONG_WIN)
	i(GL_PHONG_HINT_WIN)
	i(GL_FOG_SPECULAR_TEXTURE_WIN)
	i(GL_FRAGMENT_MATERIAL_EXT)
	i(GL_FRAGMENT_NORMAL_EXT)
	i(GL_FRAGMENT_COLOR_EXT)
	i(GL_ATTENUATION_EXT)
	i(GL_SHADOW_ATTENUATION_EXT)
	i(GL_TEXTURE_APPLICATION_MODE_EXT)
	i(GL_TEXTURE_LIGHT_EXT)
	i(GL_TEXTURE_MATERIAL_FACE_EXT)
	i(GL_TEXTURE_MATERIAL_PARAMETER_EXT)
	i(GL_ALPHA_MIN_SGIX)
	i(GL_ALPHA_MAX_SGIX)
	i(GL_PIXEL_TEX_GEN_Q_CEILING_SGIX)
	i(GL_PIXEL_TEX_GEN_Q_ROUND_SGIX)
	i(GL_PIXEL_TEX_GEN_Q_FLOOR_SGIX)
	i(GL_PIXEL_TEX_GEN_ALPHA_REPLACE_SGIX)
	i(GL_PIXEL_TEX_GEN_ALPHA_NO_REPLACE_SGIX)
	i(GL_PIXEL_TEX_GEN_ALPHA_LS_SGIX)
	i(GL_PIXEL_TEX_GEN_ALPHA_MS_SGIX)
	i(GL_BGR_EXT)
	i(GL_BGRA_EXT)
	i(GL_ASYNC_MARKER_SGIX)
	i(GL_ASYNC_TEX_IMAGE_SGIX)
	i(GL_ASYNC_DRAW_PIXELS_SGIX)
	i(GL_ASYNC_READ_PIXELS_SGIX)
	i(GL_MAX_ASYNC_TEX_IMAGE_SGIX)
	i(GL_MAX_ASYNC_DRAW_PIXELS_SGIX)
	i(GL_MAX_ASYNC_READ_PIXELS_SGIX)
	i(GL_ASYNC_HISTOGRAM_SGIX)
	i(GL_MAX_ASYNC_HISTOGRAM_SGIX)
	i(GL_PARALLEL_ARRAYS_INTEL)
	i(GL_VERTEX_ARRAY_PARALLEL_POINTERS_INTEL)
	i(GL_NORMAL_ARRAY_PARALLEL_POINTERS_INTEL)
	i(GL_COLOR_ARRAY_PARALLEL_POINTERS_INTEL)
	i(GL_TEXTURE_COORD_ARRAY_PARALLEL_POINTERS_INTEL)
	i(GL_OCCLUSION_TEST_HP)
	i(GL_OCCLUSION_TEST_RESULT_HP)
	i(GL_PIXEL_TRANSFORM_2D_EXT)
	i(GL_PIXEL_MAG_FILTER_EXT)
	i(GL_PIXEL_MIN_FILTER_EXT)
	i(GL_PIXEL_CUBIC_WEIGHT_EXT)
	i(GL_CUBIC_EXT)
	i(GL_AVERAGE_EXT)
	i(GL_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT)
	i(GL_MAX_PIXEL_TRANSFORM_2D_STACK_DEPTH_EXT)
	i(GL_PIXEL_TRANSFORM_2D_MATRIX_EXT)
	i(GL_LIGHT_MODEL_COLOR_CONTROL_EXT)
	i(GL_SINGLE_COLOR_EXT)
	i(GL_SEPARATE_SPECULAR_COLOR_EXT)
	i(GL_COLOR_SUM_EXT)
	i(GL_CURRENT_SECONDARY_COLOR_EXT)
	i(GL_SECONDARY_COLOR_ARRAY_SIZE_EXT)
	i(GL_SECONDARY_COLOR_ARRAY_TYPE_EXT)
	i(GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT)
	i(GL_SECONDARY_COLOR_ARRAY_POINTER_EXT)
	i(GL_SECONDARY_COLOR_ARRAY_EXT)
	i(GL_PERTURB_EXT)
	i(GL_TEXTURE_NORMAL_EXT)
	i(GL_FOG_COORDINATE_SOURCE_EXT)
	i(GL_FOG_COORDINATE_EXT)
	i(GL_FRAGMENT_DEPTH_EXT)
	i(GL_CURRENT_FOG_COORDINATE_EXT)
	i(GL_FOG_COORDINATE_ARRAY_TYPE_EXT)
	i(GL_FOG_COORDINATE_ARRAY_STRIDE_EXT)
	i(GL_FOG_COORDINATE_ARRAY_POINTER_EXT)
	i(GL_FOG_COORDINATE_ARRAY_EXT)
	i(GL_SCREEN_COORDINATES_REND)
	i(GL_INVERTED_SCREEN_W_REND)
	i(GL_TANGENT_ARRAY_EXT)
	i(GL_BINORMAL_ARRAY_EXT)
	i(GL_CURRENT_TANGENT_EXT)
	i(GL_CURRENT_BINORMAL_EXT)
	i(GL_TANGENT_ARRAY_TYPE_EXT)
	i(GL_TANGENT_ARRAY_STRIDE_EXT)
	i(GL_BINORMAL_ARRAY_TYPE_EXT)
	i(GL_BINORMAL_ARRAY_STRIDE_EXT)
	i(GL_TANGENT_ARRAY_POINTER_EXT)
	i(GL_BINORMAL_ARRAY_POINTER_EXT)
	i(GL_MAP1_TANGENT_EXT)
	i(GL_MAP2_TANGENT_EXT)
	i(GL_MAP1_BINORMAL_EXT)
	i(GL_MAP2_BINORMAL_EXT)
	i(GL_COMBINE_EXT)
	i(GL_COMBINE_RGB_EXT)
	i(GL_COMBINE_ALPHA_EXT)
	i(GL_RGB_SCALE_EXT)
	i(GL_ADD_SIGNED_EXT)
	i(GL_INTERPOLATE_EXT)
	i(GL_CONSTANT_EXT)
	i(GL_PRIMARY_COLOR_EXT)
	i(GL_PREVIOUS_EXT)
	i(GL_SOURCE0_RGB_EXT)
	i(GL_SOURCE1_RGB_EXT)
	i(GL_SOURCE2_RGB_EXT)
	i(GL_SOURCE0_ALPHA_EXT)
	i(GL_SOURCE1_ALPHA_EXT)
	i(GL_SOURCE2_ALPHA_EXT)
	i(GL_OPERAND0_RGB_EXT)
	i(GL_OPERAND1_RGB_EXT)
	i(GL_OPERAND2_RGB_EXT)
	i(GL_OPERAND0_ALPHA_EXT)
	i(GL_OPERAND1_ALPHA_EXT)
	i(GL_OPERAND2_ALPHA_EXT)
	i(GL_LIGHT_MODEL_SPECULAR_VECTOR_APPLE)
	i(GL_TRANSFORM_HINT_APPLE)
	i(GL_FOG_SCALE_SGIX)
	i(GL_FOG_SCALE_VALUE_SGIX)
	i(GL_UNPACK_CONSTANT_DATA_SUNX)
	i(GL_TEXTURE_CONSTANT_DATA_SUNX)
	i(GL_GLOBAL_ALPHA_SUN)
	i(GL_GLOBAL_ALPHA_FACTOR_SUN)
	i(GL_RESTART_SUN)
	i(GL_REPLACE_MIDDLE_SUN)
	i(GL_REPLACE_OLDEST_SUN)
	i(GL_TRIANGLE_LIST_SUN)
	i(GL_REPLACEMENT_CODE_SUN)
	i(GL_REPLACEMENT_CODE_ARRAY_SUN)
	i(GL_REPLACEMENT_CODE_ARRAY_TYPE_SUN)
	i(GL_REPLACEMENT_CODE_ARRAY_STRIDE_SUN)
	i(GL_REPLACEMENT_CODE_ARRAY_POINTER_SUN)
	i(GL_R1UI_V3F_SUN)
	i(GL_R1UI_C4UB_V3F_SUN)
	i(GL_R1UI_C3F_V3F_SUN)
	i(GL_R1UI_N3F_V3F_SUN)
	i(GL_R1UI_C4F_N3F_V3F_SUN)
	i(GL_R1UI_T2F_V3F_SUN)
	i(GL_R1UI_T2F_N3F_V3F_SUN)
	i(GL_R1UI_T2F_C4F_N3F_V3F_SUN)
	i(GL_BLEND_DST_RGB_EXT)
	i(GL_BLEND_SRC_RGB_EXT)
	i(GL_BLEND_DST_ALPHA_EXT)
	i(GL_BLEND_SRC_ALPHA_EXT)
	i(GL_RED_MIN_CLAMP_INGR)
	i(GL_GREEN_MIN_CLAMP_INGR)
	i(GL_BLUE_MIN_CLAMP_INGR)
	i(GL_ALPHA_MIN_CLAMP_INGR)
	i(GL_RED_MAX_CLAMP_INGR)
	i(GL_GREEN_MAX_CLAMP_INGR)
	i(GL_BLUE_MAX_CLAMP_INGR)
	i(GL_ALPHA_MAX_CLAMP_INGR)
	i(GL_INTERLACE_READ_INGR)
	i(GL_INCR_WRAP_EXT)
	i(GL_DECR_WRAP_EXT)
	i(GL_422_EXT)
	i(GL_422_REV_EXT)
	i(GL_422_AVERAGE_EXT)
	i(GL_422_REV_AVERAGE_EXT)
	i(GL_NORMAL_MAP_NV)
	i(GL_REFLECTION_MAP_NV)
	i(GL_NORMAL_MAP_EXT)
	i(GL_REFLECTION_MAP_EXT)
	i(GL_TEXTURE_CUBE_MAP_EXT)
	i(GL_TEXTURE_BINDING_CUBE_MAP_EXT)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_X_EXT)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_X_EXT)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Y_EXT)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Y_EXT)
	i(GL_TEXTURE_CUBE_MAP_POSITIVE_Z_EXT)
	i(GL_TEXTURE_CUBE_MAP_NEGATIVE_Z_EXT)
	i(GL_PROXY_TEXTURE_CUBE_MAP_EXT)
	i(GL_MAX_CUBE_MAP_TEXTURE_SIZE_EXT)
	i(GL_WRAP_BORDER_SUN)
	i(GL_MAX_TEXTURE_LOD_BIAS_EXT)
	i(GL_TEXTURE_FILTER_CONTROL_EXT)
	i(GL_TEXTURE_LOD_BIAS_EXT)
	i(GL_TEXTURE_MAX_ANISOTROPY_EXT)
	i(GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT)
	i(GL_MODELVIEW0_STACK_DEPTH_EXT)
	i(GL_MODELVIEW1_STACK_DEPTH_EXT)
	i(GL_MODELVIEW0_MATRIX_EXT)
	i(GL_MODELVIEW1_MATRIX_EXT)
	i(GL_VERTEX_WEIGHTING_EXT)
	i(GL_MODELVIEW0_EXT)
	i(GL_MODELVIEW1_EXT)
	i(GL_CURRENT_VERTEX_WEIGHT_EXT)
	i(GL_VERTEX_WEIGHT_ARRAY_EXT)
	i(GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT)
	i(GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT)
	i(GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT)
	i(GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT)
	i(GL_MAX_SHININESS_NV)
	i(GL_MAX_SPOT_EXPONENT_NV)
	i(GL_VERTEX_ARRAY_RANGE_NV)
	i(GL_VERTEX_ARRAY_RANGE_LENGTH_NV)
	i(GL_VERTEX_ARRAY_RANGE_VALID_NV)
	i(GL_MAX_VERTEX_ARRAY_RANGE_ELEMENT_NV)
	i(GL_VERTEX_ARRAY_RANGE_POINTER_NV)
	i(GL_REGISTER_COMBINERS_NV)
	i(GL_VARIABLE_A_NV)
	i(GL_VARIABLE_B_NV)
	i(GL_VARIABLE_C_NV)
	i(GL_VARIABLE_D_NV)
	i(GL_VARIABLE_E_NV)
	i(GL_VARIABLE_F_NV)
	i(GL_VARIABLE_G_NV)
	i(GL_CONSTANT_COLOR0_NV)
	i(GL_CONSTANT_COLOR1_NV)
	i(GL_PRIMARY_COLOR_NV)
	i(GL_SECONDARY_COLOR_NV)
	i(GL_SPARE0_NV)
	i(GL_SPARE1_NV)
	i(GL_DISCARD_NV)
	i(GL_E_TIMES_F_NV)
	i(GL_SPARE0_PLUS_SECONDARY_COLOR_NV)
	i(GL_UNSIGNED_IDENTITY_NV)
	i(GL_UNSIGNED_INVERT_NV)
	i(GL_EXPAND_NORMAL_NV)
	i(GL_EXPAND_NEGATE_NV)
	i(GL_HALF_BIAS_NORMAL_NV)
	i(GL_HALF_BIAS_NEGATE_NV)
	i(GL_SIGNED_IDENTITY_NV)
	i(GL_SIGNED_NEGATE_NV)
	i(GL_SCALE_BY_TWO_NV)
	i(GL_SCALE_BY_FOUR_NV)
	i(GL_SCALE_BY_ONE_HALF_NV)
	i(GL_BIAS_BY_NEGATIVE_ONE_HALF_NV)
	i(GL_COMBINER_INPUT_NV)
	i(GL_COMBINER_MAPPING_NV)
	i(GL_COMBINER_COMPONENT_USAGE_NV)
	i(GL_COMBINER_AB_DOT_PRODUCT_NV)
	i(GL_COMBINER_CD_DOT_PRODUCT_NV)
	i(GL_COMBINER_MUX_SUM_NV)
	i(GL_COMBINER_SCALE_NV)
	i(GL_COMBINER_BIAS_NV)
	i(GL_COMBINER_AB_OUTPUT_NV)
	i(GL_COMBINER_CD_OUTPUT_NV)
	i(GL_COMBINER_SUM_OUTPUT_NV)
	i(GL_MAX_GENERAL_COMBINERS_NV)
	i(GL_NUM_GENERAL_COMBINERS_NV)
	i(GL_COLOR_SUM_CLAMP_NV)
	i(GL_COMBINER0_NV)
	i(GL_COMBINER1_NV)
	i(GL_COMBINER2_NV)
	i(GL_COMBINER3_NV)
	i(GL_COMBINER4_NV)
	i(GL_COMBINER5_NV)
	i(GL_COMBINER6_NV)
	i(GL_COMBINER7_NV)
	i(GL_FOG_DISTANCE_MODE_NV)
	i(GL_EYE_RADIAL_NV)
	i(GL_EYE_PLANE_ABSOLUTE_NV)
	i(GL_EMBOSS_LIGHT_NV)
	i(GL_EMBOSS_CONSTANT_NV)
	i(GL_EMBOSS_MAP_NV)
	i(GL_COMBINE4_NV)
	i(GL_SOURCE3_RGB_NV)
	i(GL_SOURCE3_ALPHA_NV)
	i(GL_OPERAND3_RGB_NV)
	i(GL_OPERAND3_ALPHA_NV)
	i(GL_COMPRESSED_RGB_S3TC_DXT1_EXT)
	i(GL_COMPRESSED_RGBA_S3TC_DXT1_EXT)
	i(GL_COMPRESSED_RGBA_S3TC_DXT3_EXT)
	i(GL_COMPRESSED_RGBA_S3TC_DXT5_EXT)
	i(GL_CULL_VERTEX_IBM)
	i(GL_VERTEX_ARRAY_LIST_IBM)
	i(GL_NORMAL_ARRAY_LIST_IBM)
	i(GL_COLOR_ARRAY_LIST_IBM)
	i(GL_INDEX_ARRAY_LIST_IBM)
	i(GL_TEXTURE_COORD_ARRAY_LIST_IBM)
	i(GL_EDGE_FLAG_ARRAY_LIST_IBM)
	i(GL_FOG_COORDINATE_ARRAY_LIST_IBM)
	i(GL_SECONDARY_COLOR_ARRAY_LIST_IBM)
	i(GL_VERTEX_ARRAY_LIST_STRIDE_IBM)
	i(GL_NORMAL_ARRAY_LIST_STRIDE_IBM)
	i(GL_COLOR_ARRAY_LIST_STRIDE_IBM)
	i(GL_INDEX_ARRAY_LIST_STRIDE_IBM)
	i(GL_TEXTURE_COORD_ARRAY_LIST_STRIDE_IBM)
	i(GL_EDGE_FLAG_ARRAY_LIST_STRIDE_IBM)
	i(GL_FOG_COORDINATE_ARRAY_LIST_STRIDE_IBM)
	i(GL_SECONDARY_COLOR_ARRAY_LIST_STRIDE_IBM)
	i(GL_PACK_SUBSAMPLE_RATE_SGIX)
	i(GL_UNPACK_SUBSAMPLE_RATE_SGIX)
	i(GL_PIXEL_SUBSAMPLE_4444_SGIX)
	i(GL_PIXEL_SUBSAMPLE_2424_SGIX)
	i(GL_PIXEL_SUBSAMPLE_4242_SGIX)
	i(GL_YCRCB_SGIX)
	i(GL_YCRCBA_SGIX)
	i(GL_DEPTH_PASS_INSTRUMENT_SGIX)
	i(GL_DEPTH_PASS_INSTRUMENT_COUNTERS_SGIX)
	i(GL_DEPTH_PASS_INSTRUMENT_MAX_SGIX)
	i(GL_COMPRESSED_RGB_FXT1_3DFX)
	i(GL_COMPRESSED_RGBA_FXT1_3DFX)
	i(GL_MULTISAMPLE_3DFX)
	i(GL_SAMPLE_BUFFERS_3DFX)
	i(GL_SAMPLES_3DFX)
	i(GL_MULTISAMPLE_BIT_3DFX)
	i(GL_MULTISAMPLE_EXT)
	i(GL_SAMPLE_ALPHA_TO_MASK_EXT)
	i(GL_SAMPLE_ALPHA_TO_ONE_EXT)
	i(GL_SAMPLE_MASK_EXT)
	i(GL_1PASS_EXT)
	i(GL_2PASS_0_EXT)
	i(GL_2PASS_1_EXT)
	i(GL_4PASS_0_EXT)
	i(GL_4PASS_1_EXT)
	i(GL_4PASS_2_EXT)
	i(GL_4PASS_3_EXT)
	i(GL_SAMPLE_BUFFERS_EXT)
	i(GL_SAMPLES_EXT)
	i(GL_SAMPLE_MASK_VALUE_EXT)
	i(GL_SAMPLE_MASK_INVERT_EXT)
	i(GL_SAMPLE_PATTERN_EXT)
	i(GL_MULTISAMPLE_BIT_EXT)
	i(GL_VERTEX_PRECLIP_SGIX)
	i(GL_VERTEX_PRECLIP_HINT_SGIX)
	i(GL_CONVOLUTION_HINT_SGIX)
	i(GL_PACK_RESAMPLE_SGIX)
	i(GL_UNPACK_RESAMPLE_SGIX)
	i(GL_RESAMPLE_REPLICATE_SGIX)
	i(GL_RESAMPLE_ZERO_FILL_SGIX)
	i(GL_RESAMPLE_DECIMATE_SGIX)
	i(GL_EYE_DISTANCE_TO_POINT_SGIS)
	i(GL_OBJECT_DISTANCE_TO_POINT_SGIS)
	i(GL_EYE_DISTANCE_TO_LINE_SGIS)
	i(GL_OBJECT_DISTANCE_TO_LINE_SGIS)
	i(GL_EYE_POINT_SGIS)
	i(GL_OBJECT_POINT_SGIS)
	i(GL_EYE_LINE_SGIS)
	i(GL_OBJECT_LINE_SGIS)
	i(GL_TEXTURE_COLOR_WRITEMASK_SGIS)
	i(GL_DOT3_RGB_EXT)
	i(GL_DOT3_RGBA_EXT)
	i(GL_MIRROR_CLAMP_ATI)
	i(GL_MIRROR_CLAMP_TO_EDGE_ATI)
	i(GL_ALL_COMPLETED_NV)
	i(GL_FENCE_STATUS_NV)
	i(GL_FENCE_CONDITION_NV)
	i(GL_MIRRORED_REPEAT_IBM)
	i(GL_EVAL_2D_NV)
	i(GL_EVAL_TRIANGULAR_2D_NV)
	i(GL_MAP_TESSELLATION_NV)
	i(GL_MAP_ATTRIB_U_ORDER_NV)
	i(GL_MAP_ATTRIB_V_ORDER_NV)
	i(GL_EVAL_FRACTIONAL_TESSELLATION_NV)
	i(GL_EVAL_VERTEX_ATTRIB0_NV)
	i(GL_EVAL_VERTEX_ATTRIB1_NV)
	i(GL_EVAL_VERTEX_ATTRIB2_NV)
	i(GL_EVAL_VERTEX_ATTRIB3_NV)
	i(GL_EVAL_VERTEX_ATTRIB4_NV)
	i(GL_EVAL_VERTEX_ATTRIB5_NV)
	i(GL_EVAL_VERTEX_ATTRIB6_NV)
	i(GL_EVAL_VERTEX_ATTRIB7_NV)
	i(GL_EVAL_VERTEX_ATTRIB8_NV)
	i(GL_EVAL_VERTEX_ATTRIB9_NV)
	i(GL_EVAL_VERTEX_ATTRIB10_NV)
	i(GL_EVAL_VERTEX_ATTRIB11_NV)
	i(GL_EVAL_VERTEX_ATTRIB12_NV)
	i(GL_EVAL_VERTEX_ATTRIB13_NV)
	i(GL_EVAL_VERTEX_ATTRIB14_NV)
	i(GL_EVAL_VERTEX_ATTRIB15_NV)
	i(GL_MAX_MAP_TESSELLATION_NV)
	i(GL_MAX_RATIONAL_EVAL_ORDER_NV)
	i(GL_DEPTH_STENCIL_NV)
	i(GL_UNSIGNED_INT_24_8_NV)
	i(GL_PER_STAGE_CONSTANTS_NV)
	i(GL_TEXTURE_RECTANGLE_NV)
	i(GL_TEXTURE_BINDING_RECTANGLE_NV)
	i(GL_PROXY_TEXTURE_RECTANGLE_NV)
	i(GL_MAX_RECTANGLE_TEXTURE_SIZE_NV)
	i(GL_OFFSET_TEXTURE_RECTANGLE_NV)
	i(GL_OFFSET_TEXTURE_RECTANGLE_SCALE_NV)
	i(GL_DOT_PRODUCT_TEXTURE_RECTANGLE_NV)
	i(GL_RGBA_UNSIGNED_DOT_PRODUCT_MAPPING_NV)
	i(GL_UNSIGNED_INT_S8_S8_8_8_NV)
	i(GL_UNSIGNED_INT_8_8_S8_S8_REV_NV)
	i(GL_DSDT_MAG_INTENSITY_NV)
	i(GL_SHADER_CONSISTENT_NV)
	i(GL_TEXTURE_SHADER_NV)
	i(GL_SHADER_OPERATION_NV)
	i(GL_CULL_MODES_NV)
	i(GL_OFFSET_TEXTURE_MATRIX_NV)
	i(GL_OFFSET_TEXTURE_SCALE_NV)
	i(GL_OFFSET_TEXTURE_BIAS_NV)
	i(GL_OFFSET_TEXTURE_2D_MATRIX_NV)
	i(GL_OFFSET_TEXTURE_2D_SCALE_NV)
	i(GL_OFFSET_TEXTURE_2D_BIAS_NV)
	i(GL_PREVIOUS_TEXTURE_INPUT_NV)
	i(GL_CONST_EYE_NV)
	i(GL_PASS_THROUGH_NV)
	i(GL_CULL_FRAGMENT_NV)
	i(GL_OFFSET_TEXTURE_2D_NV)
	i(GL_DEPENDENT_AR_TEXTURE_2D_NV)
	i(GL_DEPENDENT_GB_TEXTURE_2D_NV)
	i(GL_DOT_PRODUCT_NV)
	i(GL_DOT_PRODUCT_DEPTH_REPLACE_NV)
	i(GL_DOT_PRODUCT_TEXTURE_2D_NV)
	i(GL_DOT_PRODUCT_TEXTURE_CUBE_MAP_NV)
	i(GL_DOT_PRODUCT_DIFFUSE_CUBE_MAP_NV)
	i(GL_DOT_PRODUCT_REFLECT_CUBE_MAP_NV)
	i(GL_DOT_PRODUCT_CONST_EYE_REFLECT_CUBE_MAP_NV)
	i(GL_HILO_NV)
	i(GL_DSDT_NV)
	i(GL_DSDT_MAG_NV)
	i(GL_DSDT_MAG_VIB_NV)
	i(GL_HILO16_NV)
	i(GL_SIGNED_HILO_NV)
	i(GL_SIGNED_HILO16_NV)
	i(GL_SIGNED_RGBA_NV)
	i(GL_SIGNED_RGBA8_NV)
	i(GL_SIGNED_RGB_NV)
	i(GL_SIGNED_RGB8_NV)
	i(GL_SIGNED_LUMINANCE_NV)
	i(GL_SIGNED_LUMINANCE8_NV)
	i(GL_SIGNED_LUMINANCE_ALPHA_NV)
	i(GL_SIGNED_LUMINANCE8_ALPHA8_NV)
	i(GL_SIGNED_ALPHA_NV)
	i(GL_SIGNED_ALPHA8_NV)
	i(GL_SIGNED_INTENSITY_NV)
	i(GL_SIGNED_INTENSITY8_NV)
	i(GL_DSDT8_NV)
	i(GL_DSDT8_MAG8_NV)
	i(GL_DSDT8_MAG8_INTENSITY8_NV)
	i(GL_SIGNED_RGB_UNSIGNED_ALPHA_NV)
	i(GL_SIGNED_RGB8_UNSIGNED_ALPHA8_NV)
	i(GL_HI_SCALE_NV)
	i(GL_LO_SCALE_NV)
	i(GL_DS_SCALE_NV)
	i(GL_DT_SCALE_NV)
	i(GL_MAGNITUDE_SCALE_NV)
	i(GL_VIBRANCE_SCALE_NV)
	i(GL_HI_BIAS_NV)
	i(GL_LO_BIAS_NV)
	i(GL_DS_BIAS_NV)
	i(GL_DT_BIAS_NV)
	i(GL_MAGNITUDE_BIAS_NV)
	i(GL_VIBRANCE_BIAS_NV)
	i(GL_TEXTURE_BORDER_VALUES_NV)
	i(GL_TEXTURE_HI_SIZE_NV)
	i(GL_TEXTURE_LO_SIZE_NV)
	i(GL_TEXTURE_DS_SIZE_NV)
	i(GL_TEXTURE_DT_SIZE_NV)
	i(GL_TEXTURE_MAG_SIZE_NV)
	i(GL_DOT_PRODUCT_TEXTURE_3D_NV)
	i(GL_VERTEX_ARRAY_RANGE_WITHOUT_FLUSH_NV)
	i(GL_VERTEX_PROGRAM_NV)
	i(GL_VERTEX_STATE_PROGRAM_NV)
	i(GL_ATTRIB_ARRAY_SIZE_NV)
	i(GL_ATTRIB_ARRAY_STRIDE_NV)
	i(GL_ATTRIB_ARRAY_TYPE_NV)
	i(GL_CURRENT_ATTRIB_NV)
	i(GL_PROGRAM_LENGTH_NV)
	i(GL_PROGRAM_STRING_NV)
	i(GL_MODELVIEW_PROJECTION_NV)
	i(GL_IDENTITY_NV)
	i(GL_INVERSE_NV)
	i(GL_TRANSPOSE_NV)
	i(GL_INVERSE_TRANSPOSE_NV)
	i(GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV)
	i(GL_MAX_TRACK_MATRICES_NV)
	i(GL_MATRIX0_NV)
	i(GL_MATRIX1_NV)
	i(GL_MATRIX2_NV)
	i(GL_MATRIX3_NV)
	i(GL_MATRIX4_NV)
	i(GL_MATRIX5_NV)
	i(GL_MATRIX6_NV)
	i(GL_MATRIX7_NV)
	i(GL_CURRENT_MATRIX_STACK_DEPTH_NV)
	i(GL_CURRENT_MATRIX_NV)
	i(GL_VERTEX_PROGRAM_POINT_SIZE_NV)
	i(GL_VERTEX_PROGRAM_TWO_SIDE_NV)
	i(GL_PROGRAM_PARAMETER_NV)
	i(GL_ATTRIB_ARRAY_POINTER_NV)
	i(GL_PROGRAM_TARGET_NV)
	i(GL_PROGRAM_RESIDENT_NV)
	i(GL_TRACK_MATRIX_NV)
	i(GL_TRACK_MATRIX_TRANSFORM_NV)
	i(GL_VERTEX_PROGRAM_BINDING_NV)
	i(GL_PROGRAM_ERROR_POSITION_NV)
	i(GL_VERTEX_ATTRIB_ARRAY0_NV)
	i(GL_VERTEX_ATTRIB_ARRAY1_NV)
	i(GL_VERTEX_ATTRIB_ARRAY2_NV)
	i(GL_VERTEX_ATTRIB_ARRAY3_NV)
	i(GL_VERTEX_ATTRIB_ARRAY4_NV)
	i(GL_VERTEX_ATTRIB_ARRAY5_NV)
	i(GL_VERTEX_ATTRIB_ARRAY6_NV)
	i(GL_VERTEX_ATTRIB_ARRAY7_NV)
	i(GL_VERTEX_ATTRIB_ARRAY8_NV)
	i(GL_VERTEX_ATTRIB_ARRAY9_NV)
	i(GL_VERTEX_ATTRIB_ARRAY10_NV)
	i(GL_VERTEX_ATTRIB_ARRAY11_NV)
	i(GL_VERTEX_ATTRIB_ARRAY12_NV)
	i(GL_VERTEX_ATTRIB_ARRAY13_NV)
	i(GL_VERTEX_ATTRIB_ARRAY14_NV)
	i(GL_VERTEX_ATTRIB_ARRAY15_NV)
	i(GL_MAP1_VERTEX_ATTRIB0_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB1_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB2_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB3_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB4_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB5_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB6_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB7_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB8_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB9_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB10_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB11_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB12_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB13_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB14_4_NV)
	i(GL_MAP1_VERTEX_ATTRIB15_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB0_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB1_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB2_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB3_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB4_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB5_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB6_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB7_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB8_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB9_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB10_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB11_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB12_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB13_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB14_4_NV)
	i(GL_MAP2_VERTEX_ATTRIB15_4_NV)
	i(GL_TEXTURE_MAX_CLAMP_S_SGIX)
	i(GL_TEXTURE_MAX_CLAMP_T_SGIX)
	i(GL_TEXTURE_MAX_CLAMP_R_SGIX)
	i(GL_SCALEBIAS_HINT_SGIX)
	i(GL_INTERLACE_OML)
	i(GL_INTERLACE_READ_OML)
	i(GL_FORMAT_SUBSAMPLE_24_24_OML)
	i(GL_FORMAT_SUBSAMPLE_244_244_OML)
	i(GL_PACK_RESAMPLE_OML)
	i(GL_UNPACK_RESAMPLE_OML)
	i(GL_RESAMPLE_REPLICATE_OML)
	i(GL_RESAMPLE_ZERO_FILL_OML)
	i(GL_RESAMPLE_AVERAGE_OML)
	i(GL_RESAMPLE_DECIMATE_OML)
	i(GL_DEPTH_STENCIL_TO_RGBA_NV)
	i(GL_DEPTH_STENCIL_TO_BGRA_NV)
	i(GL_BUMP_ROT_MATRIX_ATI)
	i(GL_BUMP_ROT_MATRIX_SIZE_ATI)
	i(GL_BUMP_NUM_TEX_UNITS_ATI)
	i(GL_BUMP_TEX_UNITS_ATI)
	i(GL_DUDV_ATI)
	i(GL_DU8DV8_ATI)
	i(GL_BUMP_ENVMAP_ATI)
	i(GL_BUMP_TARGET_ATI)
	i(GL_FRAGMENT_SHADER_ATI)
	i(GL_REG_0_ATI)
	i(GL_REG_1_ATI)
	i(GL_REG_2_ATI)
	i(GL_REG_3_ATI)
	i(GL_REG_4_ATI)
	i(GL_REG_5_ATI)
	i(GL_REG_6_ATI)
	i(GL_REG_7_ATI)
	i(GL_REG_8_ATI)
	i(GL_REG_9_ATI)
	i(GL_REG_10_ATI)
	i(GL_REG_11_ATI)
	i(GL_REG_12_ATI)
	i(GL_REG_13_ATI)
	i(GL_REG_14_ATI)
	i(GL_REG_15_ATI)
	i(GL_REG_16_ATI)
	i(GL_REG_17_ATI)
	i(GL_REG_18_ATI)
	i(GL_REG_19_ATI)
	i(GL_REG_20_ATI)
	i(GL_REG_21_ATI)
	i(GL_REG_22_ATI)
	i(GL_REG_23_ATI)
	i(GL_REG_24_ATI)
	i(GL_REG_25_ATI)
	i(GL_REG_26_ATI)
	i(GL_REG_27_ATI)
	i(GL_REG_28_ATI)
	i(GL_REG_29_ATI)
	i(GL_REG_30_ATI)
	i(GL_REG_31_ATI)
	i(GL_CON_0_ATI)
	i(GL_CON_1_ATI)
	i(GL_CON_2_ATI)
	i(GL_CON_3_ATI)
	i(GL_CON_4_ATI)
	i(GL_CON_5_ATI)
	i(GL_CON_6_ATI)
	i(GL_CON_7_ATI)
	i(GL_CON_8_ATI)
	i(GL_CON_9_ATI)
	i(GL_CON_10_ATI)
	i(GL_CON_11_ATI)
	i(GL_CON_12_ATI)
	i(GL_CON_13_ATI)
	i(GL_CON_14_ATI)
	i(GL_CON_15_ATI)
	i(GL_CON_16_ATI)
	i(GL_CON_17_ATI)
	i(GL_CON_18_ATI)
	i(GL_CON_19_ATI)
	i(GL_CON_20_ATI)
	i(GL_CON_21_ATI)
	i(GL_CON_22_ATI)
	i(GL_CON_23_ATI)
	i(GL_CON_24_ATI)
	i(GL_CON_25_ATI)
	i(GL_CON_26_ATI)
	i(GL_CON_27_ATI)
	i(GL_CON_28_ATI)
	i(GL_CON_29_ATI)
	i(GL_CON_30_ATI)
	i(GL_CON_31_ATI)
	i(GL_MOV_ATI)
	i(GL_ADD_ATI)
	i(GL_MUL_ATI)
	i(GL_SUB_ATI)
	i(GL_DOT3_ATI)
	i(GL_DOT4_ATI)
	i(GL_MAD_ATI)
	i(GL_LERP_ATI)
	i(GL_CND_ATI)
	i(GL_CND0_ATI)
	i(GL_DOT2_ADD_ATI)
	i(GL_SECONDARY_INTERPOLATOR_ATI)
	i(GL_NUM_FRAGMENT_REGISTERS_ATI)
	i(GL_NUM_FRAGMENT_CONSTANTS_ATI)
	i(GL_NUM_PASSES_ATI)
	i(GL_NUM_INSTRUCTIONS_PER_PASS_ATI)
	i(GL_NUM_INSTRUCTIONS_TOTAL_ATI)
	i(GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI)
	i(GL_NUM_LOOPBACK_COMPONENTS_ATI)
	i(GL_COLOR_ALPHA_PAIRING_ATI)
	i(GL_SWIZZLE_STR_ATI)
	i(GL_SWIZZLE_STQ_ATI)
	i(GL_SWIZZLE_STR_DR_ATI)
	i(GL_SWIZZLE_STQ_DQ_ATI)
	i(GL_SWIZZLE_STRQ_ATI)
	i(GL_SWIZZLE_STRQ_DQ_ATI)
	i(GL_RED_BIT_ATI)
	i(GL_GREEN_BIT_ATI)
	i(GL_BLUE_BIT_ATI)
	i(GL_2X_BIT_ATI)
	i(GL_4X_BIT_ATI)
	i(GL_8X_BIT_ATI)
	i(GL_HALF_BIT_ATI)
	i(GL_QUARTER_BIT_ATI)
	i(GL_EIGHTH_BIT_ATI)
	i(GL_SATURATE_BIT_ATI)
	i(GL_COMP_BIT_ATI)
	i(GL_NEGATE_BIT_ATI)
	i(GL_BIAS_BIT_ATI)
	i(GL_PN_TRIANGLES_ATI)
	i(GL_MAX_PN_TRIANGLES_TESSELATION_LEVEL_ATI)
	i(GL_PN_TRIANGLES_POINT_MODE_ATI)
	i(GL_PN_TRIANGLES_NORMAL_MODE_ATI)
	i(GL_PN_TRIANGLES_TESSELATION_LEVEL_ATI)
	i(GL_PN_TRIANGLES_POINT_MODE_LINEAR_ATI)
	i(GL_PN_TRIANGLES_POINT_MODE_CUBIC_ATI)
	i(GL_PN_TRIANGLES_NORMAL_MODE_LINEAR_ATI)
	i(GL_PN_TRIANGLES_NORMAL_MODE_QUADRATIC_ATI)
	i(GL_STATIC_ATI)
	i(GL_DYNAMIC_ATI)
	i(GL_PRESERVE_ATI)
	i(GL_DISCARD_ATI)
	i(GL_OBJECT_BUFFER_SIZE_ATI)
	i(GL_OBJECT_BUFFER_USAGE_ATI)
	i(GL_ARRAY_OBJECT_BUFFER_ATI)
	i(GL_ARRAY_OBJECT_OFFSET_ATI)
	i(GL_VERTEX_SHADER_EXT)
	i(GL_VERTEX_SHADER_BINDING_EXT)
	i(GL_OP_INDEX_EXT)
	i(GL_OP_NEGATE_EXT)
	i(GL_OP_DOT3_EXT)
	i(GL_OP_DOT4_EXT)
	i(GL_OP_MUL_EXT)
	i(GL_OP_ADD_EXT)
	i(GL_OP_MADD_EXT)
	i(GL_OP_FRAC_EXT)
	i(GL_OP_MAX_EXT)
	i(GL_OP_MIN_EXT)
	i(GL_OP_SET_GE_EXT)
	i(GL_OP_SET_LT_EXT)
	i(GL_OP_CLAMP_EXT)
	i(GL_OP_FLOOR_EXT)
	i(GL_OP_ROUND_EXT)
	i(GL_OP_EXP_BASE_2_EXT)
	i(GL_OP_LOG_BASE_2_EXT)
	i(GL_OP_POWER_EXT)
	i(GL_OP_RECIP_EXT)
	i(GL_OP_RECIP_SQRT_EXT)
	i(GL_OP_SUB_EXT)
	i(GL_OP_CROSS_PRODUCT_EXT)
	i(GL_OP_MULTIPLY_MATRIX_EXT)
	i(GL_OP_MOV_EXT)
	i(GL_OUTPUT_VERTEX_EXT)
	i(GL_OUTPUT_COLOR0_EXT)
	i(GL_OUTPUT_COLOR1_EXT)
	i(GL_OUTPUT_TEXTURE_COORD0_EXT)
	i(GL_OUTPUT_TEXTURE_COORD1_EXT)
	i(GL_OUTPUT_TEXTURE_COORD2_EXT)
	i(GL_OUTPUT_TEXTURE_COORD3_EXT)
	i(GL_OUTPUT_TEXTURE_COORD4_EXT)
	i(GL_OUTPUT_TEXTURE_COORD5_EXT)
	i(GL_OUTPUT_TEXTURE_COORD6_EXT)
	i(GL_OUTPUT_TEXTURE_COORD7_EXT)
	i(GL_OUTPUT_TEXTURE_COORD8_EXT)
	i(GL_OUTPUT_TEXTURE_COORD9_EXT)
	i(GL_OUTPUT_TEXTURE_COORD10_EXT)
	i(GL_OUTPUT_TEXTURE_COORD11_EXT)
	i(GL_OUTPUT_TEXTURE_COORD12_EXT)
	i(GL_OUTPUT_TEXTURE_COORD13_EXT)
	i(GL_OUTPUT_TEXTURE_COORD14_EXT)
	i(GL_OUTPUT_TEXTURE_COORD15_EXT)
	i(GL_OUTPUT_TEXTURE_COORD16_EXT)
	i(GL_OUTPUT_TEXTURE_COORD17_EXT)
	i(GL_OUTPUT_TEXTURE_COORD18_EXT)
	i(GL_OUTPUT_TEXTURE_COORD19_EXT)
	i(GL_OUTPUT_TEXTURE_COORD20_EXT)
	i(GL_OUTPUT_TEXTURE_COORD21_EXT)
	i(GL_OUTPUT_TEXTURE_COORD22_EXT)
	i(GL_OUTPUT_TEXTURE_COORD23_EXT)
	i(GL_OUTPUT_TEXTURE_COORD24_EXT)
	i(GL_OUTPUT_TEXTURE_COORD25_EXT)
	i(GL_OUTPUT_TEXTURE_COORD26_EXT)
	i(GL_OUTPUT_TEXTURE_COORD27_EXT)
	i(GL_OUTPUT_TEXTURE_COORD28_EXT)
	i(GL_OUTPUT_TEXTURE_COORD29_EXT)
	i(GL_OUTPUT_TEXTURE_COORD30_EXT)
	i(GL_OUTPUT_TEXTURE_COORD31_EXT)
	i(GL_OUTPUT_FOG_EXT)
	i(GL_SCALAR_EXT)
	i(GL_VECTOR_EXT)
	i(GL_MATRIX_EXT)
	i(GL_VARIANT_EXT)
	i(GL_INVARIANT_EXT)
	i(GL_LOCAL_CONSTANT_EXT)
	i(GL_LOCAL_EXT)
	i(GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT)
	i(GL_MAX_VERTEX_SHADER_VARIANTS_EXT)
	i(GL_MAX_VERTEX_SHADER_INVARIANTS_EXT)
	i(GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
	i(GL_MAX_VERTEX_SHADER_LOCALS_EXT)
	i(GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT)
	i(GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT)
	i(GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
	i(GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT)
	i(GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT)
	i(GL_VERTEX_SHADER_INSTRUCTIONS_EXT)
	i(GL_VERTEX_SHADER_VARIANTS_EXT)
	i(GL_VERTEX_SHADER_INVARIANTS_EXT)
	i(GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT)
	i(GL_VERTEX_SHADER_LOCALS_EXT)
	i(GL_VERTEX_SHADER_OPTIMIZED_EXT)
	i(GL_X_EXT)
	i(GL_Y_EXT)
	i(GL_Z_EXT)
	i(GL_W_EXT)
	i(GL_NEGATIVE_X_EXT)
	i(GL_NEGATIVE_Y_EXT)
	i(GL_NEGATIVE_Z_EXT)
	i(GL_NEGATIVE_W_EXT)
	i(GL_ZERO_EXT)
	i(GL_ONE_EXT)
	i(GL_NEGATIVE_ONE_EXT)
	i(GL_NORMALIZED_RANGE_EXT)
	i(GL_FULL_RANGE_EXT)
	i(GL_CURRENT_VERTEX_EXT)
	i(GL_MVP_MATRIX_EXT)
	i(GL_VARIANT_VALUE_EXT)
	i(GL_VARIANT_DATATYPE_EXT)
	i(GL_VARIANT_ARRAY_STRIDE_EXT)
	i(GL_VARIANT_ARRAY_TYPE_EXT)
	i(GL_VARIANT_ARRAY_EXT)
	i(GL_VARIANT_ARRAY_POINTER_EXT)
	i(GL_INVARIANT_VALUE_EXT)
	i(GL_INVARIANT_DATATYPE_EXT)
	i(GL_LOCAL_CONSTANT_VALUE_EXT)
	i(GL_LOCAL_CONSTANT_DATATYPE_EXT)
	i(GL_MAX_VERTEX_STREAMS_ATI)
	i(GL_VERTEX_STREAM0_ATI)
	i(GL_VERTEX_STREAM1_ATI)
	i(GL_VERTEX_STREAM2_ATI)
	i(GL_VERTEX_STREAM3_ATI)
	i(GL_VERTEX_STREAM4_ATI)
	i(GL_VERTEX_STREAM5_ATI)
	i(GL_VERTEX_STREAM6_ATI)
	i(GL_VERTEX_STREAM7_ATI)
	i(GL_VERTEX_SOURCE_ATI)
	i(GL_ELEMENT_ARRAY_ATI)
	i(GL_ELEMENT_ARRAY_TYPE_ATI)
	i(GL_ELEMENT_ARRAY_POINTER_ATI)
	i(GL_QUAD_MESH_SUN)
	i(GL_TRIANGLE_MESH_SUN)
	i(GL_SLICE_ACCUM_SUN)
	i(GL_MULTISAMPLE_FILTER_HINT_NV)
	i(GL_DEPTH_CLAMP_NV)
	i(GL_PIXEL_COUNTER_BITS_NV)
	i(GL_CURRENT_OCCLUSION_QUERY_ID_NV)
	i(GL_PIXEL_COUNT_NV)
	i(GL_PIXEL_COUNT_AVAILABLE_NV)
	i(GL_POINT_SPRITE_NV)
	i(GL_COORD_REPLACE_NV)
	i(GL_POINT_SPRITE_R_MODE_NV)
	i(GL_OFFSET_PROJECTIVE_TEXTURE_2D_NV)
	i(GL_OFFSET_PROJECTIVE_TEXTURE_2D_SCALE_NV)
	i(GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_NV)
	i(GL_OFFSET_PROJECTIVE_TEXTURE_RECTANGLE_SCALE_NV)
	i(GL_OFFSET_HILO_TEXTURE_2D_NV)
	i(GL_OFFSET_HILO_TEXTURE_RECTANGLE_NV)
	i(GL_OFFSET_HILO_PROJECTIVE_TEXTURE_2D_NV)
	i(GL_OFFSET_HILO_PROJECTIVE_TEXTURE_RECTANGLE_NV)
	i(GL_DEPENDENT_HILO_TEXTURE_2D_NV)
	i(GL_DEPENDENT_RGB_TEXTURE_3D_NV)
	i(GL_DEPENDENT_RGB_TEXTURE_CUBE_MAP_NV)
	i(GL_DOT_PRODUCT_PASS_THROUGH_NV)
	i(GL_DOT_PRODUCT_TEXTURE_1D_NV)
	i(GL_DOT_PRODUCT_AFFINE_DEPTH_REPLACE_NV)
	i(GL_HILO8_NV)
	i(GL_SIGNED_HILO8_NV)
	i(GL_FORCE_BLUE_TO_ONE_NV)
	i(GL_STENCIL_TEST_TWO_SIDE_EXT)
	i(GL_ACTIVE_STENCIL_FACE_EXT)
	i(GL_TEXT_FRAGMENT_SHADER_ATI)
	i(GL_UNPACK_CLIENT_STORAGE_APPLE)
	i(GL_ELEMENT_ARRAY_APPLE)
	i(GL_ELEMENT_ARRAY_TYPE_APPLE)
	i(GL_ELEMENT_ARRAY_POINTER_APPLE)
	i(GL_DRAW_PIXELS_APPLE)
	i(GL_FENCE_APPLE)
	i(GL_VERTEX_ARRAY_BINDING_APPLE)
	i(GL_VERTEX_ARRAY_RANGE_APPLE)
	i(GL_VERTEX_ARRAY_RANGE_LENGTH_APPLE)
	i(GL_VERTEX_ARRAY_STORAGE_HINT_APPLE)
	i(GL_VERTEX_ARRAY_RANGE_POINTER_APPLE)
	i(GL_STORAGE_CACHED_APPLE)
	i(GL_STORAGE_SHARED_APPLE)
	i(GL_YCBCR_422_APPLE)
	i(GL_UNSIGNED_SHORT_8_8_APPLE)
	i(GL_UNSIGNED_SHORT_8_8_REV_APPLE)
	i(GL_RGB_S3TC)
	i(GL_RGB4_S3TC)
	i(GL_RGBA_S3TC)
	i(GL_RGBA4_S3TC)
	i(GL_MAX_DRAW_BUFFERS_ATI)
	i(GL_DRAW_BUFFER0_ATI)
	i(GL_DRAW_BUFFER1_ATI)
	i(GL_DRAW_BUFFER2_ATI)
	i(GL_DRAW_BUFFER3_ATI)
	i(GL_DRAW_BUFFER4_ATI)
	i(GL_DRAW_BUFFER5_ATI)
	i(GL_DRAW_BUFFER6_ATI)
	i(GL_DRAW_BUFFER7_ATI)
	i(GL_DRAW_BUFFER8_ATI)
	i(GL_DRAW_BUFFER9_ATI)
	i(GL_DRAW_BUFFER10_ATI)
	i(GL_DRAW_BUFFER11_ATI)
	i(GL_DRAW_BUFFER12_ATI)
	i(GL_DRAW_BUFFER13_ATI)
	i(GL_DRAW_BUFFER14_ATI)
	i(GL_DRAW_BUFFER15_ATI)
	i(GL_TYPE_RGBA_FLOAT_ATI)
	i(GL_COLOR_CLEAR_UNCLAMPED_VALUE_ATI)
	i(GL_MODULATE_ADD_ATI)
	i(GL_MODULATE_SIGNED_ADD_ATI)
	i(GL_MODULATE_SUBTRACT_ATI)
	i(GL_RGBA_FLOAT32_ATI)
	i(GL_RGB_FLOAT32_ATI)
	i(GL_ALPHA_FLOAT32_ATI)
	i(GL_INTENSITY_FLOAT32_ATI)
	i(GL_LUMINANCE_FLOAT32_ATI)
	i(GL_LUMINANCE_ALPHA_FLOAT32_ATI)
	i(GL_RGBA_FLOAT16_ATI)
	i(GL_RGB_FLOAT16_ATI)
	i(GL_ALPHA_FLOAT16_ATI)
	i(GL_INTENSITY_FLOAT16_ATI)
	i(GL_LUMINANCE_FLOAT16_ATI)
	i(GL_LUMINANCE_ALPHA_FLOAT16_ATI)
	i(GL_FLOAT_R_NV)
	i(GL_FLOAT_RG_NV)
	i(GL_FLOAT_RGB_NV)
	i(GL_FLOAT_RGBA_NV)
	i(GL_FLOAT_R16_NV)
	i(GL_FLOAT_R32_NV)
	i(GL_FLOAT_RG16_NV)
	i(GL_FLOAT_RG32_NV)
	i(GL_FLOAT_RGB16_NV)
	i(GL_FLOAT_RGB32_NV)
	i(GL_FLOAT_RGBA16_NV)
	i(GL_FLOAT_RGBA32_NV)
	i(GL_TEXTURE_FLOAT_COMPONENTS_NV)
	i(GL_FLOAT_CLEAR_COLOR_VALUE_NV)
	i(GL_FLOAT_RGBA_MODE_NV)
	i(GL_MAX_FRAGMENT_PROGRAM_LOCAL_PARAMETERS_NV)
	i(GL_FRAGMENT_PROGRAM_NV)
	i(GL_MAX_TEXTURE_COORDS_NV)
	i(GL_MAX_TEXTURE_IMAGE_UNITS_NV)
	i(GL_FRAGMENT_PROGRAM_BINDING_NV)
	i(GL_PROGRAM_ERROR_STRING_NV)
	i(GL_HALF_FLOAT_NV)
	i(GL_WRITE_PIXEL_DATA_RANGE_NV)
	i(GL_READ_PIXEL_DATA_RANGE_NV)
	i(GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV)
	i(GL_READ_PIXEL_DATA_RANGE_LENGTH_NV)
	i(GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV)
	i(GL_READ_PIXEL_DATA_RANGE_POINTER_NV)
	i(GL_PRIMITIVE_RESTART_NV)
	i(GL_PRIMITIVE_RESTART_INDEX_NV)
	i(GL_TEXTURE_UNSIGNED_REMAP_MODE_NV)
	i(GL_STENCIL_BACK_FUNC_ATI)
	i(GL_STENCIL_BACK_FAIL_ATI)
	i(GL_STENCIL_BACK_PASS_DEPTH_FAIL_ATI)
	i(GL_STENCIL_BACK_PASS_DEPTH_PASS_ATI)
	i(GL_IMPLEMENTATION_COLOR_READ_TYPE_OES)
	i(GL_IMPLEMENTATION_COLOR_READ_FORMAT_OES)
	i(GL_DEPTH_BOUNDS_TEST_EXT)
	i(GL_DEPTH_BOUNDS_EXT)
	i(GL_MIRROR_CLAMP_EXT)
	i(GL_MIRROR_CLAMP_TO_EDGE_EXT)
	i(GL_MIRROR_CLAMP_TO_BORDER_EXT)
	i(GL_BLEND_EQUATION_RGB_EXT)
	i(GL_BLEND_EQUATION_ALPHA_EXT)
	i(GL_PACK_INVERT_MESA)
	i(GL_UNSIGNED_SHORT_8_8_MESA)
	i(GL_UNSIGNED_SHORT_8_8_REV_MESA)
	i(GL_YCBCR_MESA)
	i(GL_PIXEL_PACK_BUFFER_EXT)
	i(GL_PIXEL_UNPACK_BUFFER_EXT)
	i(GL_PIXEL_PACK_BUFFER_BINDING_EXT)
	i(GL_PIXEL_UNPACK_BUFFER_BINDING_EXT)
	i(GL_MAX_PROGRAM_EXEC_INSTRUCTIONS_NV)
	i(GL_MAX_PROGRAM_CALL_DEPTH_NV)
	i(GL_MAX_PROGRAM_IF_DEPTH_NV)
	i(GL_MAX_PROGRAM_LOOP_DEPTH_NV)
	i(GL_MAX_PROGRAM_LOOP_COUNT_NV)
	i(GL_INVALID_FRAMEBUFFER_OPERATION_EXT)
	i(GL_MAX_RENDERBUFFER_SIZE_EXT)
	i(GL_FRAMEBUFFER_BINDING_EXT)
	i(GL_RENDERBUFFER_BINDING_EXT)
	i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT)
	i(GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT)
	i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT)
	i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT)
	i(GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT)
	i(GL_FRAMEBUFFER_COMPLETE_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_DUPLICATE_ATTACHMENT_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT)
	i(GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT)
	i(GL_FRAMEBUFFER_UNSUPPORTED_EXT)
	i(GL_MAX_COLOR_ATTACHMENTS_EXT)
	i(GL_COLOR_ATTACHMENT0_EXT)
	i(GL_COLOR_ATTACHMENT1_EXT)
	i(GL_COLOR_ATTACHMENT2_EXT)
	i(GL_COLOR_ATTACHMENT3_EXT)
	i(GL_COLOR_ATTACHMENT4_EXT)
	i(GL_COLOR_ATTACHMENT5_EXT)
	i(GL_COLOR_ATTACHMENT6_EXT)
	i(GL_COLOR_ATTACHMENT7_EXT)
	i(GL_COLOR_ATTACHMENT8_EXT)
	i(GL_COLOR_ATTACHMENT9_EXT)
	i(GL_COLOR_ATTACHMENT10_EXT)
	i(GL_COLOR_ATTACHMENT11_EXT)
	i(GL_COLOR_ATTACHMENT12_EXT)
	i(GL_COLOR_ATTACHMENT13_EXT)
	i(GL_COLOR_ATTACHMENT14_EXT)
	i(GL_COLOR_ATTACHMENT15_EXT)
	i(GL_DEPTH_ATTACHMENT_EXT)
	i(GL_STENCIL_ATTACHMENT_EXT)
	i(GL_FRAMEBUFFER_EXT)
	i(GL_RENDERBUFFER_EXT)
	i(GL_RENDERBUFFER_WIDTH_EXT)
	i(GL_RENDERBUFFER_HEIGHT_EXT)
	i(GL_RENDERBUFFER_INTERNAL_FORMAT_EXT)
	i(GL_STENCIL_INDEX1_EXT)
	i(GL_STENCIL_INDEX4_EXT)
	i(GL_STENCIL_INDEX8_EXT)
	i(GL_STENCIL_INDEX16_EXT)
	i(GL_RENDERBUFFER_RED_SIZE_EXT)
	i(GL_RENDERBUFFER_GREEN_SIZE_EXT)
	i(GL_RENDERBUFFER_BLUE_SIZE_EXT)
	i(GL_RENDERBUFFER_ALPHA_SIZE_EXT)
	i(GL_RENDERBUFFER_DEPTH_SIZE_EXT)
	i(GL_RENDERBUFFER_STENCIL_SIZE_EXT)
#endif

	i(GL_CURRENT_BIT)
	i(GL_POINT_BIT)
	i(GL_LINE_BIT)
	i(GL_POLYGON_BIT)
	i(GL_POLYGON_STIPPLE_BIT)
	i(GL_PIXEL_MODE_BIT)
	i(GL_LIGHTING_BIT)
	i(GL_FOG_BIT)
	i(GL_DEPTH_BUFFER_BIT)
	i(GL_ACCUM_BUFFER_BIT)
	i(GL_STENCIL_BUFFER_BIT)
	i(GL_VIEWPORT_BIT)
	i(GL_TRANSFORM_BIT)
	i(GL_ENABLE_BIT)
	i(GL_COLOR_BUFFER_BIT)
	i(GL_HINT_BIT)
	i(GL_EVAL_BIT)
	i(GL_LIST_BIT)
	i(GL_TEXTURE_BIT)
	i(GL_SCISSOR_BIT)
	i(GL_ALL_ATTRIB_BITS)
	i(GL_CLIENT_PIXEL_STORE_BIT)
	i(GL_CLIENT_VERTEX_ARRAY_BIT)

	i(MAX_GL_TEXPARAMETER_COUNT)
	i(MAX_GL_TEXENV_COUNT)
	i(MAX_GL_TEXGEN_COUNT)
	i(MAX_GL_MATERIAL_COUNT)
	i(MAX_GL_MAP_COUNT)
	i(MAX_GL_LIGHT_COUNT)
	i(MAX_GL_LIGHTMODEL_COUNT)
	i(MAX_GL_FOG_COUNT)
	i(MAX_GL_GET_COUNT)

#ifdef GL_VERSION_2_1
	i(CURRENT_RASTER_SECONDARY_COLOR)
	i(FLOAT_MAT2x3)
	i(FLOAT_MAT2x4)
	i(FLOAT_MAT3x2)
	i(FLOAT_MAT3x4)
	i(FLOAT_MAT4x2)
	i(FLOAT_MAT4x3)
	i(SRGB)
	i(SRGB8)
	i(SRGB_ALPHA)
	i(SRGB8_ALPHA8)
	i(SLUMINANCE_ALPHA)
	i(SLUMINANCE8_ALPHA8)
	i(SLUMINANCE)
	i(SLUMINANCE8)
	i(COMPRESSED_SRGB)
	i(COMPRESSED_SRGB_ALPHA)
	i(COMPRESSED_SLUMINANCE)
	i(COMPRESSED_SLUMINANCE_ALPHA)
	i(PIXEL_PACK_BUFFER)
	i(PIXEL_UNPACK_BUFFER)
	i(PIXEL_PACK_BUFFER_BINDING)
	i(PIXEL_UNPACK_BUFFER_BINDING)
	i(GL_MAX_ELEMENTS_VERTICES)
	i(GL_MAX_ELEMENTS_INDICES)
#endif

/* 
 * Mesa 3D version 3.3 and 3.4 define GL_ALL_CLIENT_ATTRIB_BITS The
 * OpenGL Specification (1.1 and 1.2) defines this macro as well. Older
 * versions of Mesa3D used to have GL_CLIENT_ALL_ATTRIB_BITS. Older
 * versions of this module, and much code out there also uses this older
 * macro.
 * 
 * To be fully backward compatible, but also to be correct, both will be
 * defined here, copied from each other. This should ensure that this
 * compiles and works against any OpenGL library that uses either, and
 * allow code that uses either.
 */
#if defined(GL_ALL_CLIENT_ATTRIB_BITS) && !defined(GL_CLIENT_ALL_ATTRIB_BITS)
#define GL_CLIENT_ALL_ATTRIB_BITS GL_ALL_CLIENT_ATTRIB_BITS
#elif !defined(GL_ALL_CLIENT_ATTRIB_BITS) && defined(GL_CLIENT_ALL_ATTRIB_BITS)
#define GL_ALL_CLIENT_ATTRIB_BITS GL_CLIENT_ALL_ATTRIB_BITS
#endif
	i(GL_ALL_CLIENT_ATTRIB_BITS)
	i(GL_CLIENT_ALL_ATTRIB_BITS)
}
/* else */
#endif
